@@ -525,6 +525,7 @@ OC.L10N.register(
     "No results" : "Disoc'h ebet",
     "Done" : "Graet",
     "Grid view" : "Diskwell ar roued",
+    "Reload" : "Adkargañ",
     "Waiting for others to join the call …" : "O c'hortoz ma teuio ar re all er gemenadenn ...",
     "You can invite others in the participant tab of the sidebar" : "Galout a rit kouviañ tud gant an daolenn lodek er verenn gostez",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galout a rit kouviañ tud en dolenn lodek er varenn gostez pe rannañ al liamm-mañ evit kouviañ anezho !",
@@ -629,9 +630,10 @@ OC.L10N.register(
     "Link to a conversation" : "Liamm d'an diviz",
     "Search conversations or users" : "Klask divizoù ha implijourienn",
     "Select conversation" : "Choaz un diviz",
+    "Notification settings" : "Arventennoù kemennadennoù",
+    "Default language" : "Yezh dre ziouer",
     "Select location for attachments" : "Choazit ul lec'h evit stagañ",
     "Error while setting attachment folder" : "Ur fazi a zo bet en ur lakaat an teuliad stagañ",
-    "Notification settings" : "Arventennoù kemennadennoù",
     "Privacy" : "Prevezder",
     "Attachments folder" : "Teuliad stag",
     "Search" : "Klask",
@@ -661,7 +663,6 @@ OC.L10N.register(
     "Mute others" : "Lakaat ar re all mut",
     "Keep" : "Mirout",
     "Submit" : "Kinnig",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Kemenn hp meneg",
     "Mention myself" : "Meneg ac'hanon",
     "The conversation does not exist" : "N'ez eus ket eus an diviz-mañ",
@@ -679,14 +680,13 @@ OC.L10N.register(
     "Default" : "Dre ziouer",
     "Group" : "Stollad",
     "You: {lastMessage}" : "C'hwi : {lastMessage}",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ho klask mont en diviz emaoc'h p'ho peus un dalc'h en ur prenestr pe ardivink all. N'eo ket douget c'hoaz gant Nextcloud Talk. Petra o peus c'hoant ober ?",
     "Leave this page" : "Kuitaat ar bajenn",
     "Join here" : "Kejañ amañ",
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
     "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "Lost connection to signaling server. Trying to reconnect." : "Kenstagadenn gant ar servijour arhent kollet. O klask adkemprenn.",
-    "Establishing signaling connection is taking longer than expected …" : "Lakaat an arhent kenstagañ a zo hiroc'h eget gortozet ...",
-    "Failed to establish signaling connection. Retrying …" : "C'hwitet da lakaat an arhent kemprenn. O klask en dro ...",
     "Please reload the page." : "Mar-plij adkargit ar bajenn",
     "Do not disturb" : "Na rannit ket",
     "Away" : "Pell",
