@@ -404,6 +404,7 @@ OC.L10N.register(
     "Reset" : "איפוס",
     "Cancel" : "ביטול",
     "Back" : "חזרה",
+    "Meeting" : "מפגש",
     "Loading …" : "בטעינה…",
     "From" : "מאת",
     "To" : "אל",
@@ -415,6 +416,7 @@ OC.L10N.register(
     "Done" : "הסתיים",
     "Speaker view" : "תצוגת דובר",
     "Grid view" : "תצוגת טבלה",
+    "Reload" : "טעינה מחדש",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
@@ -437,7 +439,6 @@ OC.L10N.register(
     "Disable" : "השבתה",
     "Choose" : "בחר",
     "Restricted" : "מוגבלת",
-    "Meeting" : "מפגש",
     "Conversation settings" : "הגדרות דיון",
     "Personal" : "אישי",
     "Leave conversation" : "יציאה מהדיון",
@@ -455,6 +456,7 @@ OC.L10N.register(
     "Log content" : "תוכן הרישום",
     "Notifications" : "התראות",
     "Important conversation" : "דיון חשוב",
+    "In {conversation}" : "בתוך {conversation}",
     "Join" : "הצטרף",
     "Error while creating the conversation" : "שגיאה ביצירת הדיון",
     "Create conversation" : "יצירת דיון",
@@ -483,14 +485,17 @@ OC.L10N.register(
     "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Upload" : "העלאה",
     "Files" : "קבצים",
+    "24 hours" : "24 שעות",
     "Reply" : "תגובה",
     "More actions" : "פעולות נוספות",
     "Go to file" : "מעבר לקובץ",
     "Translate" : "תרגום",
+    "React with {emoji}" : "הגיבו עם {emoji}",
     "Dismiss" : "התעלמות",
     "Message sent" : "הודעה נשלחה",
     "Deleting message" : "ההודעה נמחקה",
     "Contact" : "איש/אשת קשר",
+    "_%n reply_::_%n replies_" : ["תגובה אחת","%n תגובות","%n תגובות"],
     "No messages" : "אין הודעות",
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
     "Add participants" : "הוספת משתתפים",
@@ -522,17 +527,20 @@ OC.L10N.register(
     "Participants" : "משתתפים",
     "Chat" : "צ׳אט",
     "Details" : "פרטים",
+    "No results found" : "לא נמצאו תוצאות",
     "Load more results" : "לטעון עוד תוצאות",
     "Projects" : "מיזמים",
     "Link to a conversation" : "קישור לדיון",
     "Select conversation" : "בחירת דיון",
-    "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
     "Notification settings" : "הגדרות התראה",
+    "Default language" : "שפת בררת מחדל",
+    "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
     "Privacy" : "פרטיות",
     "Attachments folder" : "תיקיית הקבצים המצורפים",
     "Search" : "חיפוש",
     "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
     "Start call" : "התחלת שיחה",
+    "React with {reaction}" : "הגיבו עם {reaction}",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
     "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
@@ -543,7 +551,6 @@ OC.L10N.register(
     "Keep" : "שימור",
     "Select a region" : "נא לבחור איזור",
     "Submit" : "שליחה",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "הודעה ללא אזכור",
     "Mention myself" : "אזכור עצמי",
     "The conversation does not exist" : "הדיון לא קיים",
@@ -588,6 +595,7 @@ OC.L10N.register(
     "Other" : "אחר",
     "Default" : "בררת מחדל",
     "Group" : "קבוצה",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Please reload the page." : "יש להעלות מחדש דף זה.",
