@@ -345,7 +345,6 @@ OC.L10N.register(
     "Zambia" : "Zambija",
     "Zimbabwe" : "Zimbabve",
     "Federation" : "Federācija",
-    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} nav uzstādīts, tas var novest pie veiktspējas sarežģījumiem, kad izmanto darbvirsmas klientus.",
     "Invalid date, date format must be YYYY-MM-DD" : "Nederīgs datums, datuma formātam jābūt YYYY-MM-DD",
     "Conversation not found" : "Saruna nav atrasta",
     "Chat, video & audio-conferencing using WebRTC" : "Video un audio konferences, izmantojot WebRTC",
@@ -496,9 +495,9 @@ OC.L10N.register(
     "Projects" : "Projekti",
     "Link to a conversation" : "Saite uz sarunu",
     "Select conversation" : "Izvēlēties sarunu",
+    "Notification settings" : "Paziņojumu iestatījumi",
     "Error while setting read status privacy" : "Kļūda lasīšanas stāvokļa privātuma iestatīšanas laikā",
     "Error while setting typing status privacy" : "Kļūda rakstīšanas stāvokļa privātuma iestatīšanas laikā",
-    "Notification settings" : "Paziņojumu iestatījumi",
     "Privacy" : "Privātums",
     "Search" : "Meklēt",
     "Start call" : "Sākt zvanu",
@@ -518,7 +517,6 @@ OC.L10N.register(
     "Keep" : "Paturēt",
     "Select a region" : "Atlasīt apgabalu",
     "Submit" : "Iesniegt",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Duplicate session" : "Pavairot sesiju",
     "Join a conversation or start a new one" : "Pievienoties sarunai vai sākt jaunu",
     "User" : "Lietotājs",
@@ -537,6 +535,7 @@ OC.L10N.register(
     "Group" : "Grupa",
     "Team" : "Komanda",
     "You and {user0} left the call" : "Tu un {user0} pametāt zvanu",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
     "Error while sharing file" : "Kļūda datnes kopīgošanā",
     "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
@@ -570,6 +569,7 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
     "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome, lai kopīgotu savu ekrānu."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome, lai kopīgotu savu ekrānu.",
+    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} nav uzstādīts, tas var novest pie veiktspējas sarežģījumiem, kad izmanto darbvirsmas klientus."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
