@@ -161,6 +161,7 @@ OC.L10N.register(
     "Dial-in information" : "Информации",
     "Meeting ID" : "ID на средба",
     "Your PIN" : "Вашиот ПИН",
+    "Talk conversation for event" : "Talk разговор за настанот",
     "Password request: %s" : "Барање за лозинка: %s",
     "Private conversation" : "Приватен разговор",
     "Deleted user (%s)" : "Избришан корисник (%s)",
@@ -169,6 +170,7 @@ OC.L10N.register(
     "Decline" : "Одбиј",
     "New message" : "Нова порака",
     "Reminder" : "Потсетник",
+    "Notification" : "Известување",
     "Reminder: You in {call}" : "Потсетник: Вие во {call}",
     "Reminder: {user} in {call}" : "Потсетник: {user} во {call}",
     "Reminder: Deleted user in {call}" : "Потсетник: Избришан корисник во {call}",
@@ -571,13 +573,16 @@ OC.L10N.register(
     "Failed" : "Неуспешно",
     "OK" : "Добро",
     "Checking …" : "Проверка ...",
+    "Federated user" : "Федерален корисник",
     "Create rooms" : "Креирај соби",
     "Confirm" : "Потврди",
     "Reset" : "Ресетирање",
     "Room {roomNumber}" : "Соба {roomNumber}",
-    "Back" : "Назад",
     "Cancel" : "Откажи",
+    "Back" : "Назад",
     "Add participant \"{user}\"" : "Додади учесник \"{user}\"",
+    "Now" : "Сега",
+    "Meeting" : "Средба",
     "Loading …" : "Се вчитува…",
     "From" : "Од",
     "To" : "До",
@@ -642,20 +647,19 @@ OC.L10N.register(
     "Restricted" : "Ограничена",
     "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Учесниците може да се придружуваат на повици, но не можат да овозможат аудио или видео, ниту да споделуваат екран додека модераторот рачно не им даде дозвола.",
     "Edit permissions" : "Уреди дозволи",
-    "Meeting" : "Средба",
     "Conversation settings" : "Параметри за разговор",
     "Basic Info" : "Основни информации",
     "Personal" : "Лично",
     "Danger zone" : "Опасна зона",
-    "Do you really want to delete \"{displayName}\"?" : "Дали навистина сакате да го избришете \"{displayName}\"?",
-    "Be careful, these actions cannot be undone." : "Бидете внимателни, овие дејства не можат да повратат.",
     "Leave conversation" : "Напушти разговор",
-    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Откако ќе излезете од разговорот, за повторно да се придружите на затворен разговор, потребна е покана. На отворен разговор може повторно да се придружите во секое време.",
     "Delete conversation" : "Избриши разговор",
+    "Do you really want to delete \"{displayName}\"?" : "Дали навистина сакате да го избришете \"{displayName}\"?",
+    "Delete all chat messages" : "Избришете ги сите пораки од разгоровот",
+    "Be careful, these actions cannot be undone." : "Бидете внимателни, овие дејства не можат да повратат.",
+    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Откако ќе излезете од разговорот, за повторно да се придружите на затворен разговор, потребна е покана. На отворен разговор може повторно да се придружите во секое време.",
     "Permanently delete this conversation." : "Трајно избришете го овој разговор",
     "Delete chat messages" : "Избришете ги пораките од разгоровот",
     "Permanently delete all the messages in this conversation." : "Трајно избришете ги сите пораки во овој разговор.",
-    "Delete all chat messages" : "Избришете ги сите пораки од разгоровот",
     "_%n hour_::_%n hours_" : ["1 час","%n часа"],
     "_%n day_::_%n days_" : ["1 ден","%n дена"],
     "_%n week_::_%n weeks_" : ["1 недела","%n недели"],
@@ -689,9 +693,9 @@ OC.L10N.register(
     "An error occurred while performing the search" : "Настана грешка при обидот за пребарување",
     "Unread messages" : "Непрочитани пораки",
     "Clear filter" : "Исчисти филтри",
-    "Talk settings" : "Параметри за Talk",
     "Users" : "Корисници",
     "Groups" : "Групи",
+    "Teams" : "Тимови",
     "No search results" : "Нема резултати од пребарувањето",
     "Users and groups" : "Корисници и групи",
     "Other sources" : "Други извори",
@@ -713,21 +717,14 @@ OC.L10N.register(
     "Blur" : "Замаглување",
     "Upload" : "Прикачи",
     "Files" : "Датотеки",
-    "Message sent" : "Пораката е испратена",
-    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
-    "Set reminder for later today" : "Постави потсетник за денес покасно",
-    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
-    "Set reminder for tomorrow" : "Постави потсетник за утре",
-    "This weekend – {timeLocale}" : "Овој викенд – {timeLocale}",
-    "Set reminder for this weekend" : "Постави потсетник за овој викенд",
-    "Next week – {timeLocale}" : "Следна недела – {timeLocale}",
-    "Set reminder for next week" : "Постави потсетник за наредната недела",
+    "24 hours" : "24 часа",
     "Clear reminder – {timeLocale}" : "Избришан потсетник – {timeLocale}",
     "Message text copied to clipboard" : "Пораката е копирана во клипборд",
     "A reminder was successfully removed" : "Потсетникот е успешно избришан",
     "A reminder was successfully set at {datetime}" : "Успешно е поставен потсетник во {datetime}",
     "Error occurred when creating a reminder" : "Настана грешка при обид за поставување потсетник",
     "Reply" : "Одговор",
+    "More actions" : "Повеќе акции",
     "Set reminder" : "Постави потсетник",
     "Edit message" : "Уреди порака",
     "Copy message link" : "Копирај линк на пораката",
@@ -739,6 +736,8 @@ OC.L10N.register(
     "Error while forwarding message" : "Грешка при препраќање на пораката",
     "The message has been forwarded to {selectedConversationName}" : "Пораката е препратена до {selectedConversationName}",
     "Dismiss" : "Отфрли",
+    "Send now" : "Испрати сега",
+    "Message sent" : "Пораката е испратена",
     "Contact" : "Контакт",
     "{stack} in {board}" : "{stack} во {board}",
     "Open poll • You voted already" : "Отворена анкета •Имате гласано",
@@ -747,6 +746,7 @@ OC.L10N.register(
     "Poll" : "Анкета",
     "See results" : "Vidi rezultati",
     "No messages" : "Нема пораки",
+    "Unpin" : "Од-ппинувај",
     "Create a new group conversation" : "Креирајте нов групен разговор",
     "Add participants" : "Додади учесници",
     "Allow guests to join via link" : "Дозволи им на гостите да се приклучат преку линк",
@@ -755,6 +755,7 @@ OC.L10N.register(
     "Send message" : "Испрати порака",
     "File to share" : "Датотека за споделување",
     "Add emoji" : "Додади емотикон",
+    "Send later" : "Испрати покасно",
     "Cancel editing" : "Откажи уредување",
     "Share from {nextcloud}" : "Сподели од {nextcloud}",
     "Share from Files" : "Сподели од датотеките",
@@ -858,34 +859,24 @@ OC.L10N.register(
     "Select conversation" : "Избери разговор",
     "Edit display name" : "Иреди име",
     "Save name" : "Зачувај име",
-    "Choose the folder in which attachments should be saved." : "Изберете ја папката во која треба да се зачуваат прилозите.",
+    "Error while saving sounds setting" : "Грешка при зачувување на параметрите за звуци",
+    "Play sounds when participants join or leave a call" : "Репродуцирајте звуци кога учесниците се придружуваат или оставаат повик",
+    "Notification settings" : "Параметри за известување",
+    "Default language" : "Стандарден јазик",
     "Select location for attachments" : "Избери локација за прилози",
     "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
-    "Your privacy setting has been saved" : "Вашите поставки за приватност се зачувани",
     "Error while setting read status privacy" : "Грешка при зачувување на поставките за приватност",
-    "Failed to save sounds setting" : "Неуспешно зачувување на параметрите за звуци",
-    "Sounds setting saved" : "Параматрите за звуци се зачувани",
-    "Error while saving sounds setting" : "Грешка при зачувување на параметрите за звуци",
-    "Attachments folder" : "Папка со прилози",
-    "Appearance" : "Изглед",
     "Privacy" : "Приватност",
-    "Share my read-status and show the read-status of others" : "Сподели го мојот статус на читање и прикажете го статусот на читање на другите",
-    "Sounds" : "Звуци",
-    "Play sounds when participants join or leave a call" : "Репродуцирајте звуци кога учесниците се придружуваат или оставаат повик",
-    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Звуците за чет и известувања за повици може да се прилагодат во личните поставки.",
-    "Keyboard shortcuts" : "Кратенки преку тастатура",
-    "Speed up your Talk experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
+    "Attachments folder" : "Папка со прилози",
+    "Toggle full screen" : "Вклучи на цел екран",
+    "Search" : "Барај",
     "Focus the chat input" : "Фокусирајте го курсорот на разговорот",
     "Unfocus the chat input to use shortcuts" : "Отстранаете го курсорот од разговорот за да користите кратенки преку тастатура",
-    "Fullscreen the chat or call" : "Цел екран на разговор или повик",
-    "Search" : "Барај",
     "Shortcuts while in a call" : "Кратенки за време на повик",
     "Camera on and off" : "Вклучување и исклучување на камерата",
     "Microphone on and off" : "Вклучување и исклучување на микрофонот",
-    "Space bar" : "Празно место",
-    "Push to talk or push to mute" : "Притисни за разговор или притисни за занемување",
     "Raise or lower hand" : "Крени или спушти рака",
-    "More actions" : "Повеќе акции",
+    "Push to talk or push to mute" : "Притисни за разговор или притисни за занемување",
     "Start call silently" : "Започни товок повик",
     "Start call" : "Повик",
     "You will be able to join the call only after a moderator starts it." : "Ќе може да се придружите на повикот само откако модераторот ќе го започне.",
@@ -918,12 +909,10 @@ OC.L10N.register(
     "Show your screen" : "Прикажи го вашиот екран",
     "Stop screensharing" : "Запри споделување на екран",
     "Mute others" : "Занеми ги останатите",
-    "Toggle full screen" : "Вклучи на цел екран",
     "Keep" : "Задржи",
     "Select a region" : "Изберете регион",
     "Submit" : "Испрати",
     "Search …" : "Пребарај ...",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Пораки без спомнувања",
     "Mention myself" : "Спомни се себеси",
     "The conversation does not exist" : "Разговорот не постои",
@@ -962,6 +951,7 @@ OC.L10N.register(
     "Group" : "Група",
     "Team" : "Тим",
     "You: {lastMessage}" : "Ти: {lastMessage}",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Се обидувате да се приклучите на разговор додека имате активна сесија во друг прозорец или уред. Ова во моментов не е поддржано. Што сакаш да правиш?",
     "Leave this page" : "Напушти ја оваа страна",
     "Join here" : "Приклучи се овде",
@@ -984,7 +974,12 @@ OC.L10N.register(
     "An error occurred while submitting your vote" : "Настана грешка при гласање",
     "An error occurred while ending the poll" : "Настана грешка при затварање на анкетата",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Прелистувачот што го користите не е целосно поддржан. Користете ја најновата верзија на Mozilla Firefox, Microsoft Edge, Google Chrome, Opera или Apple Safari.",
+    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
+    "This weekend – {timeLocale}" : "Овој викенд – {timeLocale}",
+    "Next week – {timeLocale}" : "Следна недела – {timeLocale}",
     "Conversation link copied to clipboard" : "Линк до разговорот е копиран во клипборд",
+    "Error while parsing a PROPFIND error" : "Грешка при обработка на PROPFIND грешката",
     "Please reload the page." : "Превчитајте ја страницата.",
     "Do not disturb" : "Не вознемирувај",
     "Away" : "Далеку",
@@ -1006,26 +1001,35 @@ OC.L10N.register(
     "iOS app" : "iOS апликација",
     "__language_name__" : "Македонски",
     "Tasks" : "Задачи",
-    "You tried to call {user}" : "Се обидовте да го повикате {user}",
     "%s invited you to a conversation." : "%s ве покани на разговор.",
     "You were invited to a conversation." : "Поканети сте на разговор.",
     "Click the button below to join." : "Кликнете на копчето подолу за да се приклучите.",
     "Join »%s«" : "Приклучете се »%s«",
-    "{user} invited you to a private conversation" : "{user} те покани на приватен разговор",
     "Always show the device preview screen before joining a call in this conversation." : "Секогаш прикажувај го екранот за преглед на уредот пред да се придружите на повик во овој разговор. ",
-    "Copy conversation link" : "копирај линк од разговорот",
+    "Talk settings" : "Параметри за Talk",
+    "Set reminder for later today" : "Постави потсетник за денес покасно",
+    "Set reminder for tomorrow" : "Постави потсетник за утре",
+    "Set reminder for this weekend" : "Постави потсетник за овој викенд",
+    "Set reminder for next week" : "Постави потсетник за наредната недела",
     "Today" : "Денес",
     "Yesterday" : "Вчера",
     "_%n day ago_::_%n days ago_" : ["пред %n ден","пред %n дена"],
-    "Close" : "Затвори",
+    "Choose the folder in which attachments should be saved." : "Изберете ја папката во која треба да се зачуваат прилозите.",
+    "Your privacy setting has been saved" : "Вашите поставки за приватност се зачувани",
+    "Failed to save sounds setting" : "Неуспешно зачувување на параметрите за звуци",
+    "Sounds setting saved" : "Параматрите за звуци се зачувани",
     "Choose devices" : "Избери уреди",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Разговорот беше ажуриран, треба повторно да ја вчитате страницата пред да започнете или да се придружите на повик.",
+    "Appearance" : "Изглед",
+    "Share my read-status and show the read-status of others" : "Сподели го мојот статус на читање и прикажете го статусот на читање на другите",
+    "Sounds" : "Звуци",
+    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Звуците за чет и известувања за повици може да се прилагодат во личните поставки.",
+    "Performance" : "Перформанси",
+    "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Speed up your Talk experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
+    "Fullscreen the chat or call" : "Цел екран на разговор или повик",
+    "Space bar" : "Празно место",
     "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
     "Screensharing extension is required to share your screen." : "Потребен е додаток за споделување на вашиот екран.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Користете друг прелистувач како Firefox или Chrome за да го споделите вашиот екран.",
-    "Nextcloud Talk was updated, please reload the page" : "Разговорот е ажуриран, повторно вчитајте ја страната",
-    "An error happened when trying to share your file" : "Се случи грешка при обидот за споделување на датотека",
-    "Failed to join the conversation. Try to reload the page." : "Неуспешно приклучување кон разговорот, Пробајте да ја превчитате страницата.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Активиран е мод за одржавање, превчитајте ја страницата"
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Користете друг прелистувач како Firefox или Chrome за да го споделите вашиот екран."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
