@@ -277,6 +277,7 @@ OC.L10N.register(
     "No results" : "Sem resultados",
     "Done" : "Concluído",
     "Grid view" : "Vista em grelha",
+    "Reload" : "Recarregar",
     "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
     "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
     "Share this link to invite others!" : "Envie este link para convidar outros!",
@@ -323,6 +324,8 @@ OC.L10N.register(
     "Blur" : "Blur",
     "Upload" : "Enviar",
     "Files" : "Ficheiros",
+    "24 hours" : "24 horas",
+    "7 days" : "7 dias",
     "Message forwarded to \"Note to self\"" : "Mensagem reencaminhada para \"Nota a mim\"",
     "Error while forwarding message to \"Note to self\"" : "Erro ao reencaminhar mensagem para \"Nota a mim\"",
     "Reply" : "Resposta",
@@ -356,8 +359,8 @@ OC.L10N.register(
     "Load more results" : "Mostrar mais resultados",
     "Projects" : "Projectos",
     "No shared items" : "Sem itens partilhados",
-    "Appearance & Sounds" : "Aspeto e sons",
     "Notification settings" : "Definições de notificação",
+    "Appearance & Sounds" : "Aspeto e sons",
     "Privacy" : "Privacidade",
     "Search" : "Pesquisa sobre",
     "Screensharing options" : "Opções de partilha de ecrã",
@@ -368,7 +371,6 @@ OC.L10N.register(
     "Keep" : "Manter",
     "Select a region" : "Selecione uma região",
     "Submit" : "Submeter",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "User" : "Utilizador",
     "Password" : "Palavra-passe",
     "API token" : "Token de API",
@@ -381,6 +383,7 @@ OC.L10N.register(
     "Other" : "Outro",
     "Default" : "Predefinida",
     "Group" : "Grupo",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error while sharing file" : "Erro ao partilhar ficheiro",
     "Please reload the page." : "Por favor, recarregue a página.",
     "Do not disturb" : "Não incomodar",
