@@ -31,36 +31,48 @@ OC.L10N.register(
     "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
     "Pending" : "รอดำเนินการ",
     "Error" : "ข้อผิดพลาด",
+    "Never" : "ไม่เคย",
     "Language" : "ภาษา",
     "Country" : "ประเทศ",
     "Status" : "สถานะ",
     "Created at" : "สร้างเมื่อ",
+    "Yes" : "ใช่",
+    "No" : "ไม่ตกลง",
     "OK" : "ตกลง",
     "Confirm" : "ยืนยัน",
     "Reset" : "รีเซ็ต",
-    "Back" : "ย้อนกลับ",
     "Cancel" : "ยกเลิก",
+    "Back" : "ย้อนกลับ",
     "Calendar" : "ปฏิทิน",
     "Attendees" : "ผู้เข้าร่วมกิจกรรม",
     "Save" : "บันทึก",
     "No results" : "ไม่มีผลลัพธ์",
     "Grid view" : "มุมมองแบบตาราง",
+    "Reload" : "โหลดใหม่",
     "Copy link" : "คัดลอกลิงก์",
+    "Mute audio" : "ปิดเสียง",
+    "Unmute audio" : "เลิกปิดเสียง",
     "None" : "ไม่มี",
+    "Check devices" : "ตรวจสอบอุปกรณ์",
     "Collapse" : "ย่อ",
     "Favorite" : "รายการโปรด",
     "Hide details" : "ซ่อนข้อมูล",
     "Show details" : "แสดงข้อมูล",
+    "Enter a name for this conversation" : "กรอกชื่อของการสนทนานี้",
     "Disable" : "ปิดใช้งาน",
     "Choose" : "เลือก",
     "Restricted" : "ถูกจำกัด",
     "Personal" : "ส่วนตัว",
-    "No" : "ไม่ตกลง",
-    "Yes" : "ใช่",
     "Password protection" : "ป้องกันด้วยรหัสผ่าน",
     "Edit" : "แก้ไข",
     "Delete" : "ลบ",
     "Notifications" : "การแจ้งเตือน",
+    "Start meeting now" : "เริ่มการประชุมตอนนี้",
+    "Give your meeting a title" : "ตั้งชื่อการประชุมของคุณ",
+    "Create and copy link" : "สร้างและคัดลอกลิงค์",
+    "Create a new conversation" : "สร้างการสนทนาใหม่",
+    "Open calendar" : "เปิดปฏิทิน",
+    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "ข้อความที่คุณถูกกล่าวถึงจะแสดงที่นี่ คุณสามารถกล่าวถึงผู้อื่นได้โดยการพิมพ์ @ ตามด้วยชื่อของพวกเขา",
     "Log in" : "เข้าสู่ระบบ",
     "Remove from favorites" : "เอาออกจากรายการโปรด",
     "Add to favorites" : "เพิ่มในรายการโปรด",
@@ -68,15 +80,14 @@ OC.L10N.register(
     "Users" : "ผู้ใช้",
     "Groups" : "กลุ่ม",
     "Devices" : "อุปกรณ์",
+    "Backgrounds" : "พื้นหลัง",
     "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
+    "Blur" : "เบลอ",
     "Upload" : "อัปโหลด",
     "Files" : "ไฟล์",
     "Reply" : "ตอบกลับ",
     "Translate" : "แปลภาษา",
     "Dismiss" : "ปิดทิ้ง",
-    "Today" : "วันนี้",
-    "Yesterday" : "เมื่อวาน",
-    "_%n day ago_::_%n days ago_" : ["%n วันที่ผ่านมา"],
     "Add participants" : "เพิ่มผู้เข้าร่วม",
     "New file" : "ไฟล์ใหม่",
     "Blank" : "ว่าง",
@@ -87,14 +98,14 @@ OC.L10N.register(
     "Remove" : "ลบออก",
     "Add users or groups" : "เพิ่มผู้ใช้หรือกลุ่ม",
     "Searching …" : "กำลังค้นหา …",
+    "Participants ({count})" : "ผู้เข้าร่วม ({count})",
     "Chat" : "แชท",
     "Details" : "รายละเอียด",
+    "Shared items" : "สิ่งที่แชร์",
     "Load more results" : "โหลดผลลัพธ์เพิ่มเติม",
-    "Appearance" : "ลักษณะที่ปรากฏ",
+    "Default language" : "ภาษาค่าเริ่มต้น",
     "Privacy" : "ความเป็นส่วนตัว",
-    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
     "Search" : "ค้นหา",
-    "Default" : "ค่าเริ่มต้น",
     "Keep" : "เก็บ",
     "Submit" : "ส่ง",
     "User" : "ผู้ใช้",
@@ -106,6 +117,7 @@ OC.L10N.register(
     "Locations" : "สถานที่",
     "Audio" : "เสียง",
     "Other" : "อื่น ๆ",
+    "Default" : "ค่าเริ่มต้น",
     "Group" : "กลุ่ม",
     "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
     "Do not disturb" : "ห้ามรบกวน",
@@ -116,6 +128,10 @@ OC.L10N.register(
     "__language_name__" : "ไทย",
     "Tasks" : "งาน",
     "Notes" : "โน้ต",
-    "Close" : "ปิด"
+    "Today" : "วันนี้",
+    "Yesterday" : "เมื่อวาน",
+    "_%n day ago_::_%n days ago_" : ["%n วันที่ผ่านมา"],
+    "Appearance" : "ลักษณะที่ปรากฏ",
+    "Keyboard shortcuts" : "แป้นพิมพ์ลัด"
 },
 "nplurals=1; plural=0;");
