@@ -262,11 +262,14 @@ OC.L10N.register(
     "South Africa" : "Janubiy Afrika",
     "Zambia" : "Zambiya",
     "Zimbabwe" : "Zimbabve",
+    "Federation" : "Jamg'arma",
+    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Jamg'armaning muloqot moduli yoqilgan bo'lsa, \"memcache.locking\" ni sozlash tavsiya etiladi.",
     "Everyone" : "Everyone",
     "Save changes" : "Save changes",
     "Saving …" : "Saqlanmoqda...",
     "Saved!" : "Saqlandi!",
     "Name" : "Name",
+    "Enable Federation in Talk app" : "Talk ilovasida Jamg'armani yoqish",
     "Off" : "Oʻchirilgan",
     "Enable encryption" : "Enable encryption",
     "Pending" : "Pending",
@@ -284,6 +287,7 @@ OC.L10N.register(
     "Cancel" : "Bekor qilish",
     "Back" : "Orqaga",
     "Now" : "Hozir",
+    "Meeting" : "Uchrashuv",
     "Loading …" : "Yuklanmoqda…",
     "From" : "Dan",
     "To" : "Gacha",
@@ -293,6 +297,7 @@ OC.L10N.register(
     "No results" : "Natija yo'q",
     "Done" : "Bajarildi",
     "Grid view" : "To‘r ko‘rinishi",
+    "Reload" : "Qayta yuklash",
     "Copy link" : "Havolani nusxalash",
     "None" : "Yo'q",
     "Favorite" : "Favorite",
@@ -303,7 +308,6 @@ OC.L10N.register(
     "Enable" : "Enable",
     "Choose" : "Choose",
     "Restricted" : "Cheklangan",
-    "Meeting" : "Uchrashuv",
     "Personal" : "Personal",
     "Delete conversation" : "Delete conversation",
     "_%n hour_::_%n hours_" : ["%n soat"],
@@ -325,6 +329,7 @@ OC.L10N.register(
     "Select a device" : "Qurilmani tanlang",
     "Upload" : "Yuklash",
     "Files" : "Fayllar",
+    "24 hours" : "24 soat",
     "Reply" : "Javob bering",
     "More actions" : "Ko'proq harakatlar",
     "Translate" : "Tarjima",
@@ -356,7 +361,10 @@ OC.L10N.register(
     "Other" : "Boshqa",
     "Show all files" : "Barcha fayllarni ko'rsatish",
     "Default" : "Standart",
+    "Group" : "Guruh",
+    "Team" : "Jamoa",
     "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
+    "Nextcloud Talk Federation was updated." : "Nextcloud Talkda jamg'arma yangilandi.",
     "Error while parsing a PROPFIND error" : "PROPFIND xatosini tahlil qilishda xatolik yuz berdi",
     "Please reload the page." : "Please reload the page.",
     "Do not disturb" : "Do not disturb",
