@@ -233,6 +233,243 @@ OC.L10N.register(
     "There is a problem with deleting the account. Please check your logs for further information." : "Đã xảy ra sự cố khi xóa tài khoản. Vui lòng kiểm tra nhật ký của bạn để biết thêm thông tin.",
     "Too many requests are sent from your servers address. Please try again later." : "Quá nhiều yêu cầu được gửi từ địa chỉ máy chủ của bạn. Vui lòng thử lại sau.",
     "Failed to delete the account because the trial server is unreachable. Please check back later." : "Không thể xóa tài khoản vì không thể truy cập được máy chủ dùng thử. Vui lòng kiểm tra lại sau.",
+    "Andorra" : "Andorra",
+    "United Arab Emirates" : "Các Tiểu vương quốc Ả Rập Thống nhất",
+    "Afghanistan" : "Afghanistan",
+    "Antigua and Barbuda" : "Antigua và Barbuda",
+    "Anguilla" : "Anguilla",
+    "Albania" : "Albania",
+    "Armenia" : "Armenia",
+    "Angola" : "Angola",
+    "Antarctica" : "Nam Cực",
+    "Argentina" : "Argentina",
+    "American Samoa" : "American Samoa",
+    "Austria" : "Áo",
+    "Australia" : "Úc",
+    "Aruba" : "Aruba",
+    "Åland Islands" : "Quần đảo Åland",
+    "Azerbaijan" : "Azerbaijan",
+    "Bosnia and Herzegovina" : "Bosnia và Herzegovina",
+    "Barbados" : "Barbados",
+    "Bangladesh" : "Bangladesh",
+    "Belgium" : "Bỉ",
+    "Burkina Faso" : "Burkina Faso",
+    "Bulgaria" : "Bulgaria",
+    "Bahrain" : "Bahrain",
+    "Burundi" : "Burundi",
+    "Benin" : "Benin",
+    "Saint Barthélemy" : "Saint Barthélemy",
+    "Bermuda" : "Bermuda",
+    "Brunei Darussalam" : "Brunei",
+    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius và Saba",
+    "Brazil" : "Brazil",
+    "Bahamas" : "Bahamas",
+    "Bhutan" : "Bhutan",
+    "Bouvet Island" : "Đảo Bouvet",
+    "Botswana" : "Botswana",
+    "Belarus" : "Belarus",
+    "Belize" : "Belize",
+    "Canada" : "Canada",
+    "Cocos (Keeling) Islands" : "Quần đảo Cocos (Keeling)",
+    "Central African Republic" : "Cộng hòa Trung Phi",
+    "Congo" : "Congo",
+    "Switzerland" : "Thụy Sĩ",
+    "Côte d'Ivoire" : "Bờ Biển Ngà",
+    "Cook Islands" : "Quần đảo Cook",
+    "Chile" : "Chile",
+    "Cameroon" : "Cameroon",
+    "China" : "Trung Quốc",
+    "Colombia" : "Colombia",
+    "Costa Rica" : "Costa Rica",
+    "Cuba" : "Cuba",
+    "Cabo Verde" : "Cabo Verde",
+    "Curaçao" : "Curaçao",
+    "Christmas Island" : "Đảo Christmas",
+    "Cyprus" : "Síp",
+    "Czechia" : "Séc",
+    "Germany" : "Đức",
+    "Djibouti" : "Djibouti",
+    "Denmark" : "Đan Mạch",
+    "Dominica" : "Dominica",
+    "Dominican Republic" : "Cộng hòa Dominica",
+    "Algeria" : "Algeria",
+    "Ecuador" : "Ecuador",
+    "Estonia" : "Estonia",
+    "Egypt" : "Ai Cập",
+    "Western Sahara" : "Tây Sahara",
+    "Eritrea" : "Eritrea",
+    "Spain" : "Tây Ban Nha",
+    "Ethiopia" : "Ethiopia",
+    "Finland" : "Phần Lan",
+    "Fiji" : "Fiji",
+    "Falkland Islands (Malvinas)" : "Quần đảo Falkland (Malvinas)",
+    "Faroe Islands" : "Quần đảo Faroe",
+    "France" : "Pháp",
+    "Gabon" : "Gabon",
+    "United Kingdom of Great Britain and Northern Ireland" : "Vương quốc Anh",
+    "Grenada" : "Grenada",
+    "Georgia" : "Georgia",
+    "French Guiana" : "Guiana thuộc Pháp",
+    "Guernsey" : "Guernsey",
+    "Ghana" : "Ghana",
+    "Gibraltar" : "Gibraltar",
+    "Greenland" : "Greenland",
+    "Gambia" : "Gambia",
+    "Guinea" : "Guinea",
+    "Guadeloupe" : "Guadeloupe",
+    "Equatorial Guinea" : "Xích Đạo Guinea",
+    "Greece" : "Hy Lạp",
+    "South Georgia and the South Sandwich Islands" : "Nam Georgia và Quần đảo Nam Sandwich",
+    "Guatemala" : "Guatemala",
+    "Guam" : "Guam",
+    "Guinea-Bissau" : "Guinea-Bissau",
+    "Guyana" : "Guyana",
+    "Hong Kong" : "Hồng Kông",
+    "Heard Island and McDonald Islands" : "Đảo Heard và QĐ McDonald",
+    "Honduras" : "Honduras",
+    "Croatia" : "Croatia",
+    "Haiti" : "Haiti",
+    "Hungary" : "Hungary",
+    "Indonesia" : "Indonesia",
+    "Ireland" : "Ireland",
+    "Israel" : "Israel",
+    "Isle of Man" : "Đảo Man",
+    "India" : "Ấn Độ",
+    "British Indian Ocean Territory" : "Lãnh thổ Ấn Độ Dương thuộc Anh",
+    "Iraq" : "Iraq",
+    "Iceland" : "Iceland",
+    "Italy" : "Ý",
+    "Jersey" : "Jersey",
+    "Jamaica" : "Jamaica",
+    "Jordan" : "Jordan",
+    "Japan" : "Nhật Bản",
+    "Kenya" : "Kenya",
+    "Kyrgyzstan" : "Kyrgyzstan",
+    "Cambodia" : "Campuchia",
+    "Kiribati" : "Kiribati",
+    "Comoros" : "Comoros",
+    "Saint Kitts and Nevis" : "Saint Kitts và Nevis",
+    "Kuwait" : "Kuwait",
+    "Cayman Islands" : "Quần đảo Cayman",
+    "Kazakhstan" : "Kazakhstan",
+    "Lao People's Democratic Republic" : "Lào",
+    "Lebanon" : "Li-băng",
+    "Saint Lucia" : "Saint Lucia",
+    "Liechtenstein" : "Liechtenstein",
+    "Sri Lanka" : "Sri Lanka",
+    "Liberia" : "Liberia",
+    "Lesotho" : "Lesotho",
+    "Lithuania" : "Lithuania",
+    "Luxembourg" : "Luxembourg",
+    "Latvia" : "Latvia",
+    "Libya" : "Libya",
+    "Morocco" : "Ma-rốc",
+    "Monaco" : "Monaco",
+    "Montenegro" : "Montenegro",
+    "Saint Martin (French part)" : "Saint Martin (phần thuộc Pháp)",
+    "Madagascar" : "Madagascar",
+    "Marshall Islands" : "Quần đảo Marshall",
+    "North Macedonia" : "Bắc Macedonia",
+    "Mali" : "Mali",
+    "Myanmar" : "Myanmar",
+    "Mongolia" : "Mông Cổ",
+    "Macao" : "Ma Cao",
+    "Northern Mariana Islands" : "Quần đảo Bắc Mariana",
+    "Martinique" : "Martinique",
+    "Mauritania" : "Mauritania",
+    "Montserrat" : "Montserrat",
+    "Malta" : "Malta",
+    "Mauritius" : "Mauritius",
+    "Maldives" : "Maldives",
+    "Malawi" : "Malawi",
+    "Mexico" : "Mexico",
+    "Malaysia" : "Malaysia",
+    "Mozambique" : "Mozambique",
+    "Namibia" : "Namibia",
+    "New Caledonia" : "New Caledonia",
+    "Niger" : "Niger",
+    "Norfolk Island" : "Đảo Norfolk",
+    "Nigeria" : "Nigeria",
+    "Nicaragua" : "Nicaragua",
+    "Netherlands" : "Hà Lan",
+    "Norway" : "Na Uy",
+    "Nepal" : "Nepal",
+    "Nauru" : "Nauru",
+    "Niue" : "Niue",
+    "New Zealand" : "New Zealand",
+    "Oman" : "Oman",
+    "Panama" : "Panama",
+    "Peru" : "Peru",
+    "French Polynesia" : "Polynesia thuộc Pháp",
+    "Papua New Guinea" : "Papua New Guinea",
+    "Philippines" : "Philippines",
+    "Pakistan" : "Pakistan",
+    "Poland" : "Ba Lan",
+    "Saint Pierre and Miquelon" : "Saint Pierre và Miquelon",
+    "Pitcairn" : "Pitcairn",
+    "Puerto Rico" : "Puerto Rico",
+    "Palestine, State of" : "Palestine",
+    "Portugal" : "Bồ Đào Nha",
+    "Palau" : "Palau",
+    "Paraguay" : "Paraguay",
+    "Qatar" : "Qatar",
+    "Réunion" : "Réunion",
+    "Romania" : "Romania",
+    "Serbia" : "Serbia",
+    "Russian Federation" : "Nga",
+    "Rwanda" : "Rwanda",
+    "Saudi Arabia" : "Ả Rập Xê Út",
+    "Solomon Islands" : "Quần đảo Solomon",
+    "Seychelles" : "Seychelles",
+    "Sudan" : "Sudan",
+    "Sweden" : "Thụy Điển",
+    "Singapore" : "Singapore",
+    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension và Tristan da Cunha",
+    "Slovenia" : "Slovenia",
+    "Svalbard and Jan Mayen" : "Svalbard và Jan Mayen",
+    "Slovakia" : "Slovakia",
+    "Sierra Leone" : "Sierra Leone",
+    "San Marino" : "San Marino",
+    "Senegal" : "Senegal",
+    "Somalia" : "Somalia",
+    "Suriname" : "Suriname",
+    "South Sudan" : "Nam Sudan",
+    "Sao Tome and Principe" : "Sao Tome và Principe",
+    "El Salvador" : "El Salvador",
+    "Sint Maarten (Dutch part)" : "Sint Maarten (phần thuộc Hà Lan)",
+    "Syrian Arab Republic" : "Cộng hòa Ả Rập Syria",
+    "Turks and Caicos Islands" : "Quần đảo Turks và Caicos",
+    "Chad" : "Chad",
+    "French Southern Territories" : "Vùng đất phía Nam và châu Nam Cực thuộc Pháp",
+    "Togo" : "Togo",
+    "Thailand" : "Thái Lan",
+    "Tajikistan" : "Tajikistan",
+    "Tokelau" : "Tokelau",
+    "Timor-Leste" : "Đông Timor",
+    "Turkmenistan" : "Turkmenistan",
+    "Tunisia" : "Tunisia",
+    "Tonga" : "Tonga",
+    "Turkey" : "Thổ Nhĩ Kỳ",
+    "Trinidad and Tobago" : "Trinidad và Tobago",
+    "Tuvalu" : "Tuvalu",
+    "Tanzania, United Republic of" : "Tanzania",
+    "Ukraine" : "Ukraina",
+    "Uganda" : "Uganda",
+    "United States Minor Outlying Islands" : "Các đảo nhỏ xa trung tâm Hoa Kỳ",
+    "United States of America" : "Hoa Kỳ",
+    "Uruguay" : "Uruguay",
+    "Uzbekistan" : "Uzbekistan",
+    "Holy See" : "Tòa Thánh",
+    "Saint Vincent and the Grenadines" : "Saint Vincent và Grenadines",
+    "Viet Nam" : "Việt Nam",
+    "Vanuatu" : "Vanuatu",
+    "Wallis and Futuna" : "Wallis và Futuna",
+    "Samoa" : "Samoa",
+    "Yemen" : "Yemen",
+    "Mayotte" : "Mayotte",
+    "South Africa" : "Nam Phi",
+    "Zambia" : "Zambia",
+    "Zimbabwe" : "Zimbabwe",
     "Federation" : "Kết nối Liên Bang ",
     "High-performance backend" : "Backend hiệu suất cao",
     "Error: Server did not respond with proper JSON" : "Lỗi: Máy chủ không phản hồi với JSON thích hợp",
@@ -555,11 +792,11 @@ OC.L10N.register(
     "Search conversations or users" : "Tìm kiếm cuộc trò chuyện hoặc người dùng",
     "Select conversation" : "Chọn cuộc trò chuyện",
     "Edit display name" : "Chỉnh sửa tên hiển thị",
+    "Notification settings" : "Cài đặt thông báo",
+    "Default language" : "Ngôn ngữ mặc định",
     "Select location for attachments" : "Chọn vị trí cho tệp đính kèm",
     "Error while setting attachment folder" : "Lỗi khi cấu hình thư mục tệp đính kèm",
     "Error while setting read status privacy" : "Lỗi khi đặt quyền riêng tư của trạng thái đã đọc",
-    "Failed to save sounds setting" : "Không thể lưu cài đặt âm thanh",
-    "Notification settings" : "Cài đặt thông báo",
     "Privacy" : "Bảo mật",
     "Attachments folder" : "Thư mục đính kèm",
     "Search" : "Tìm",
@@ -596,7 +833,6 @@ OC.L10N.register(
     "Keep" : "Giữ",
     "Select a region" : "Chọn một khu vực",
     "Submit" : "Gửi đi",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Message without mention" : "Tin nhắn không đề cập",
     "Mention myself" : "Nhắc đến chính mình",
     "The conversation does not exist" : "Cuộc trò chuyện không tồn tại",
@@ -654,6 +890,7 @@ OC.L10N.register(
     "Group" : "Nhóm",
     "Team" : "Đội",
     "You: {lastMessage}" : "Bạn: {lastMessage}",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Bạn đang cố gắng tham gia một cuộc trò chuyện trong khi có một phiên hoạt động trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ. Bạn muốn làm gì?",
     "Leave this page" : "Rời khỏi trang này",
     "Join here" : "Tham gia tại đây",
@@ -711,6 +948,7 @@ OC.L10N.register(
     "Today" : "Hôm nay",
     "Yesterday" : "Hôm qua",
     "Your privacy setting has been saved" : "Các thiết lập quyền riêng tư của bạn đã được lưu",
+    "Failed to save sounds setting" : "Không thể lưu cài đặt âm thanh",
     "Choose devices" : "Chọn thiết bị",
     "Appearance" : "Ngoại hình",
     "Share my read-status and show the read-status of others" : "Chia sẻ trạng thái đã đọc của tôi và hiển thị trạng thái đã đọc của những người khác",
@@ -721,9 +959,6 @@ OC.L10N.register(
     "Space bar" : "Thanh dấu cách",
     "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
     "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
-    "Establishing signaling connection is taking longer than expected …" : "Việc thiết lập kết nối báo hiệu mất nhiều thời gian hơn dự kiến…",
-    "Failed to establish signaling connection. Retrying …" : "Không thiết lập được kết nối tín hiệu. Đang thử lại…",
-    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Không thiết lập được kết nối tín hiệu. Có thể có gì đó sai trong cấu hình máy chủ báo hiệu"
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn."
 },
 "nplurals=1; plural=0;");
