@@ -88,6 +88,7 @@ class SystemMessage implements IEventListener {
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!$event instanceof MessageParseEvent) {
 			return;
@@ -143,36 +144,36 @@ class SystemMessage implements IEventListener {
 
 			$currentActorType = $participant->getAttendee()->getActorType();
 			$currentActorId = $participant->getAttendee()->getActorId();
-			$currentUserIsActor = isset($parsedParameters['actor']['server']) &&
-				$parsedParameters['actor']['type'] === 'user' &&
-				$this->currentFederatedUserDetails['user'] === $parsedParameters['actor']['id'] &&
-				$this->currentFederatedUserDetails['server'] === $parsedParameters['actor']['server'];
+			$currentUserIsActor = isset($parsedParameters['actor']['server'])
+				&& $parsedParameters['actor']['type'] === 'user'
+				&& $this->currentFederatedUserDetails['user'] === $parsedParameters['actor']['id']
+				&& $this->currentFederatedUserDetails['server'] === $parsedParameters['actor']['server'];
 		} elseif (!$participant->isGuest()) {
 			$currentActorType = $participant->getAttendee()->getActorType();
 			$currentActorId = $participant->getAttendee()->getActorId();
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user' &&
-				$participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS &&
-				$currentActorId === $parsedParameters['actor']['id'] &&
-				empty($parsedParameters['actor']['server']);
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user'
+				&& $participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS
+				&& $currentActorId === $parsedParameters['actor']['id']
+				&& empty($parsedParameters['actor']['server']);
 		} elseif ($participant->getAttendee()->getActorType() === Attendee::ACTOR_EMAILS) {
 			$currentActorType = $participant->getAttendee()->getActorType();
 			$currentActorId = $participant->getAttendee()->getActorId();
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'email' &&
-				$participant->getAttendee()->getActorType() === Attendee::ACTOR_EMAILS &&
-				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'email'
+				&& $participant->getAttendee()->getActorType() === Attendee::ACTOR_EMAILS
+				&& $participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
 		} else {
 			$currentActorType = $participant->getAttendee()->getActorType();
 			$currentActorId = $participant->getAttendee()->getActorId();
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest' &&
-				$participant->getAttendee()->getActorType() === 'guest' &&
-				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest'
+				&& $participant->getAttendee()->getActorType() === 'guest'
+				&& $participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
 		}
-		$cliIsActor = $parsedParameters['actor']['type'] === 'guest' &&
-			'guest/' . Attendee::ACTOR_ID_CLI === $parsedParameters['actor']['id'];
+		$cliIsActor = $parsedParameters['actor']['type'] === 'guest'
+			&& 'guest/' . Attendee::ACTOR_ID_CLI === $parsedParameters['actor']['id'];
 
 		if ($message === 'conversation_created') {
-			$systemIsActor = $parsedParameters['actor']['type'] === 'guest' &&
-				'guest/' . Attendee::ACTOR_ID_SYSTEM === $parsedParameters['actor']['id'];
+			$systemIsActor = $parsedParameters['actor']['type'] === 'guest'
+				&& 'guest/' . Attendee::ACTOR_ID_SYSTEM === $parsedParameters['actor']['id'];
 
 			$parsedMessage = $this->l->t('{actor} created the conversation');
 			if ($currentUserIsActor) {
@@ -571,6 +572,26 @@ class SystemMessage implements IEventListener {
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You set up Matterbridge to synchronize this conversation with other chats');
 			}
+		} elseif ($message === 'thread_created') {
+			$parsedMessage = $this->l->t('{actor} created thread {title}');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You created thread {title}');
+			}
+			$parsedParameters['title'] = [
+				'type' => 'highlight',
+				'id' => 'thread/' . $parameters['thread'],
+				'name' => $parameters['title'] ?? (string)$parameters['thread'],
+			];
+		} elseif ($message === 'thread_renamed') {
+			$parsedMessage = $this->l->t('{actor} renamed thread {title}');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You renamed thread {title}');
+			}
+			$parsedParameters['title'] = [
+				'type' => 'highlight',
+				'id' => 'thread/' . $parameters['thread'],
+				'name' => $parameters['title'],
+			];
 		} elseif ($message === 'matterbridge_config_edited') {
 			$parsedMessage = $this->l->t('{actor} updated the Matterbridge configuration');
 			if ($currentUserIsActor) {
@@ -601,6 +622,21 @@ class SystemMessage implements IEventListener {
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You edited a message');
 			}
+		} elseif ($message === 'message_pinned') {
+			$parsedMessage = $this->l->t('{actor} pinned a message');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You pinned a message');
+			}
+		} elseif ($message === 'message_unpinned') {
+			$systemIsActor = $parsedParameters['actor']['type'] === Attendee::ACTOR_GUESTS
+				&& $parsedParameters['actor']['id'] === Attendee::ACTOR_ID_SYSTEM;
+
+			$parsedMessage = $this->l->t('{actor} unpinned a message');
+			if ($systemIsActor) {
+				$parsedMessage = $this->l->t('Message was automatically unpinned');
+			} elseif ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You unpinned a message');
+			}
 		} elseif ($message === 'reaction_revoked') {
 			$parsedMessage = $this->l->t('{actor} deleted a reaction');
 			if ($currentUserIsActor) {
@@ -726,19 +762,19 @@ class SystemMessage implements IEventListener {
 				];
 			}
 
-			$currentUserIsActor = isset($parsedParameters['actor']['server']) &&
-				$parsedParameters['actor']['type'] === 'user' &&
-				$this->currentFederatedUserDetails['user'] === $parsedParameters['actor']['id'] &&
-				$this->currentFederatedUserDetails['server'] === $parsedParameters['actor']['server'];
+			$currentUserIsActor = isset($parsedParameters['actor']['server'])
+				&& $parsedParameters['actor']['type'] === 'user'
+				&& $this->currentFederatedUserDetails['user'] === $parsedParameters['actor']['id']
+				&& $this->currentFederatedUserDetails['server'] === $parsedParameters['actor']['server'];
 		} elseif (!$participant->isGuest()) {
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user' &&
-				$participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS &&
-				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'] &&
-				empty($parsedParameters['actor']['server']);
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user'
+				&& $participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS
+				&& $participant->getAttendee()->getActorId() === $parsedParameters['actor']['id']
+				&& empty($parsedParameters['actor']['server']);
 		} else {
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest' &&
-				$participant->getAttendee()->getActorType() === 'guest' &&
-				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest'
+				&& $participant->getAttendee()->getActorType() === 'guest'
+				&& $participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
 		}
 
 		if ($chatMessage->getMessageType() === ChatManager::VERB_MESSAGE_DELETED) {
@@ -767,7 +803,7 @@ class SystemMessage implements IEventListener {
 	 * @throws ShareNotFound
 	 */
 	protected function getFileFromShare(Room $room, ?Participant $participant, string $shareId, bool $allowInaccurate): array {
-		$share = $this->shareProvider->getShareById((int)$shareId);
+		$share = $this->shareProvider->getShareById($shareId);
 
 		if ($participant && $participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS) {
 			if ($allowInaccurate) {
@@ -1101,7 +1137,7 @@ class SystemMessage implements IEventListener {
 		try {
 			$participant = $this->participantService->getParticipantByActor($room, $actorType, $actorId);
 			$name = $participant->getAttendee()->getDisplayName();
-			if ($name === '' && $actorType === Attendee::ACTOR_EMAILS) {
+			if ($name === '' && $actorType === Attendee::ACTOR_EMAILS && !preg_match('/^[0-9a-f]{64}$/', $actorId)) {
 				$name = $actorId;
 			} elseif ($name === '') {
 				return $this->l->t('Guest');
