@@ -2,26 +2,8 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2018, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @author Kate Döen <kate.doeen@nextcloud.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Controller;
@@ -33,6 +15,7 @@ use OCA\Talk\Room;
 use OCA\Talk\Service\RoomService;
 use OCA\Talk\TalkSession;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\ApiRoute;
 use OCP\AppFramework\Http\Attribute\BruteForceProtection;
 use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\AppFramework\Http\Attribute\PublicPage;
@@ -88,21 +71,26 @@ class FilesIntegrationController extends OCSController {
 	 * In any case, to create or even get the token of the room, the file must
 	 * be shared and the user must be the owner of a public share of the file
 	 * (like a link share, for example) or have direct access to that file; an
-	 * error is returned otherwise. A user has direct access to a file if she
-	 * has access to it (or to an ancestor) through a user, group, circle or
-	 * room share (but not through a link share, for example), or if she is the
+	 * error is returned otherwise. A user has direct access to a file if they
+	 * have access to it (or to an ancestor) through a user, group, circle or
+	 * room share (but not through a link share, for example), or if they are the
 	 * owner of such a file.
 	 *
 	 * @param string $fileId ID of the file
-	 * @return DataResponse<Http::STATUS_OK, array{token: string}, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{token: string}, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, null, array{}>
+	 * @throws OCSNotFoundException Share not found
+	 *
 	 * 200: Room token returned
 	 * 400: Rooms not allowed for shares
-	 * @throws OCSNotFoundException Share not found
 	 */
 	#[NoAdminRequired]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/file/{fileId}', requirements: [
+		'apiVersion' => '(v1)',
+		'fileId' => '.+',
+	])]
 	public function getRoomByFileId(string $fileId): DataResponse {
 		if ($this->config->getAppValue('spreed', 'conversations_files', '1') !== '1') {
-			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			return new DataResponse(null, Http::STATUS_BAD_REQUEST);
 		}
 
 		$currentUser = $this->userSession->getUser();
@@ -116,7 +104,7 @@ class FilesIntegrationController extends OCSController {
 			throw new OCSNotFoundException($this->l->t('File is not shared, or shared but not with the user'));
 		}
 
-		$users = $this->util->getUsersWithAccessFile($fileId);
+		$users = $this->util->getUsersWithAccessFile($fileId, $currentUser->getUID());
 		if (count($users) <= 1 && !$this->util->canGuestsAccessFile($fileId)) {
 			throw new OCSNotFoundException($this->l->t('File is not shared, or shared but not with the user'));
 		}
@@ -126,7 +114,13 @@ class FilesIntegrationController extends OCSController {
 		} catch (RoomNotFoundException $e) {
 			$name = $node->getName();
 			$name = $this->roomService->prepareConversationName($name);
-			$room = $this->roomService->createConversation(Room::TYPE_PUBLIC, $name, null, 'file', $fileId);
+			$room = $this->roomService->createConversation(
+				Room::TYPE_PUBLIC,
+				$name,
+				null,
+				Room::OBJECT_TYPE_FILE,
+				$fileId,
+			);
 		}
 
 		return new DataResponse([
@@ -160,7 +154,8 @@ class FilesIntegrationController extends OCSController {
 	 * thus logged-in users as seen as guests.
 	 *
 	 * @param string $shareToken Token of the file share
-	 * @return DataResponse<Http::STATUS_OK, array{token: string, userId: string, userDisplayName: string}, array{}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array{token: string, userId: string, userDisplayName: string}, array{}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND, null, array{}>
+	 *
 	 * 200: Room token and user info returned
 	 * 400: Rooms not allowed for shares
 	 * 404: Share not found
@@ -168,10 +163,14 @@ class FilesIntegrationController extends OCSController {
 	#[PublicPage]
 	#[UseSession]
 	#[BruteForceProtection(action: 'shareinfo')]
+	#[ApiRoute(verb: 'GET', url: '/api/{apiVersion}/publicshare/{shareToken}', requirements: [
+		'apiVersion' => '(v1)',
+		'shareToken' => '.+',
+	])]
 	public function getRoomByShareToken(string $shareToken): DataResponse {
-		if ($this->config->getAppValue('spreed', 'conversations_files', '1') !== '1' ||
-			$this->config->getAppValue('spreed', 'conversations_files_public_shares', '1') !== '1') {
-			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		if ($this->config->getAppValue('spreed', 'conversations_files', '1') !== '1'
+			|| $this->config->getAppValue('spreed', 'conversations_files_public_shares', '1') !== '1') {
+			return new DataResponse(null, Http::STATUS_BAD_REQUEST);
 		}
 
 		try {
@@ -183,27 +182,33 @@ class FilesIntegrationController extends OCSController {
 				}
 			}
 		} catch (ShareNotFound $e) {
-			$response = new DataResponse([], Http::STATUS_NOT_FOUND);
+			$response = new DataResponse(null, Http::STATUS_NOT_FOUND);
 			$response->throttle(['token' => $shareToken, 'action' => 'shareinfo']);
 			return $response;
 		}
 
 		try {
 			if ($share->getNodeType() !== FileInfo::TYPE_FILE) {
-				return new DataResponse([], Http::STATUS_NOT_FOUND);
+				return new DataResponse(null, Http::STATUS_NOT_FOUND);
 			}
 
 			$fileId = (string)$share->getNodeId();
 
 			try {
 				$room = $this->manager->getRoomByObject('file', $fileId);
-			} catch (RoomNotFoundException $e) {
+			} catch (RoomNotFoundException) {
 				$name = $share->getNode()->getName();
 				$name = $this->roomService->prepareConversationName($name);
-				$room = $this->roomService->createConversation(Room::TYPE_PUBLIC, $name, null, 'file', $fileId);
+				$room = $this->roomService->createConversation(
+					Room::TYPE_PUBLIC,
+					$name,
+					null,
+					Room::OBJECT_TYPE_FILE,
+					$fileId,
+				);
 			}
-		} catch (NotFoundException $e) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
+		} catch (NotFoundException) {
+			return new DataResponse(null, Http::STATUS_NOT_FOUND);
 		}
 
 		$this->talkSession->setFileShareTokenForRoom($room->getToken(), $shareToken);
