@@ -25,6 +25,7 @@ use OCP\App\IAppManager;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\Attribute\BruteForceProtection;
+use OCP\AppFramework\Http\Attribute\FrontpageRoute;
 use OCP\AppFramework\Http\Attribute\NoCSRFRequired;
 use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\Attribute\PublicPage;
@@ -38,6 +39,7 @@ use OCP\AppFramework\Http\TemplateResponse;
 use OCP\AppFramework\Services\IInitialState;
 use OCP\Collaboration\Reference\RenderReferenceEvent;
 use OCP\Collaboration\Resources\LoadAdditionalScriptsEvent;
+use OCP\Config\IUserConfig;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Files\IRootFolder;
 use OCP\HintException;
@@ -78,6 +80,7 @@ class PageController extends Controller {
 		private IThrottler $throttler,
 		Config $talkConfig,
 		IConfig $serverConfig,
+		protected IUserConfig $userConfig,
 		IGroupManager $groupManager,
 	) {
 		parent::__construct($appName, $request);
@@ -98,6 +101,9 @@ class PageController extends Controller {
 	#[PublicPage]
 	#[UseSession]
 	#[BruteForceProtection(action: 'talkRoomToken')]
+	#[FrontpageRoute(verb: 'GET', url: '/call/{token}', requirements: [
+		'token' => '[a-z0-9]{4,30}',
+	], root: '')]
 	public function showCall(string $token, string $email = '', string $access = ''): Response {
 		// This is the entry point from the `/call/{token}` URL which is hardcoded in the server.
 		return $this->pageHandler($token, email: $email, accessToken: $access);
@@ -113,6 +119,9 @@ class PageController extends Controller {
 	#[PublicPage]
 	#[UseSession]
 	#[BruteForceProtection(action: 'talkRoomPassword')]
+	#[FrontpageRoute(verb: 'POST', url: '/call/{token}', requirements: [
+		'token' => '[a-z0-9]{4,30}',
+	], root: '')]
 	public function authenticatePassword(string $token, string $password = ''): Response {
 		// This is the entry point from the `/call/{token}` URL which is hardcoded in the server.
 		return $this->pageHandler($token, password: $password);
@@ -120,12 +129,14 @@ class PageController extends Controller {
 
 	#[NoCSRFRequired]
 	#[PublicPage]
+	#[FrontpageRoute(verb: 'GET', url: '/not-found')]
 	public function notFound(): Response {
 		return $this->pageHandler();
 	}
 
 	#[NoCSRFRequired]
 	#[PublicPage]
+	#[FrontpageRoute(verb: 'GET', url: '/duplicate-session')]
 	public function duplicateSession(): Response {
 		return $this->pageHandler();
 	}
@@ -140,6 +151,7 @@ class PageController extends Controller {
 	#[PublicPage]
 	#[BruteForceProtection(action: 'talkRoomToken')]
 	#[UseSession]
+	#[FrontpageRoute(verb: 'GET', url: '/')]
 	public function index(string $token = '', string $callUser = ''): Response {
 		if ($callUser !== '') {
 			$token = '';
@@ -294,6 +306,9 @@ class PageController extends Controller {
 	#[PublicPage]
 	#[BruteForceProtection(action: 'talkRoomToken')]
 	#[BruteForceProtection(action: 'talkRecordingStatus')]
+	#[FrontpageRoute(verb: 'GET', url: '/call/{token}/recording', requirements: [
+		'token' => '[a-z0-9]{4,30}',
+	], root: '')]
 	public function recording(string $token): Response {
 		try {
 			$room = $this->manager->getRoomByToken($token);
