@@ -27,6 +27,7 @@ use OCP\ICacheFactory;
 
 /**
  * @psalm-import-type TalkChatMentionSuggestion from ResponseDefinitions
+ * @psalm-import-type TalkChatMessage from ResponseDefinitions
  * @psalm-import-type TalkChatMessageWithParent from ResponseDefinitions
  * @psalm-import-type TalkRoom from ResponseDefinitions
  */
@@ -252,6 +253,145 @@ class ChatController {
 		return new DataResponse($data, Http::STATUS_OK, $headers);
 	}
 
+	/**
+	 * @return DataResponse<Http::STATUS_OK, array<string, list<TalkChatMessage>>, array{}>
+	 * @throws CannotReachRemoteException
+	 *
+	 * 200: List of shared objects messages of each type returned
+	 *
+	 * @see \OCA\Talk\Controller\ChatController::getObjectsSharedInRoomOverview()
+	 */
+	public function getObjectsSharedInRoomOverview(Room $room, Participant $participant, int $limit): DataResponse {
+		$proxy = $this->proxy->get(
+			$participant->getAttendee()->getInvitedCloudId(),
+			$participant->getAttendee()->getAccessToken(),
+			$room->getRemoteServer() . '/ocs/v2.php/apps/spreed/api/v1/chat/' . $room->getRemoteToken() . '/share/overview',
+			[
+				'limit' => $limit,
+			],
+		);
+
+		// We allow "200 OK" and "406 Not Acceptable" here, so that 33 against 32 and before is working well
+		/** @var array<string, list<TalkChatMessage>> $data */
+		$data = $this->proxy->getOCSData($proxy, [Http::STATUS_OK, Http::STATUS_NOT_ACCEPTABLE]);
+
+		$result = [];
+		foreach ($data as $type => $items) {
+			$result[$type] = array_values($this->userConverter->convertMessages($room, $items));
+		}
+
+		/** @var array<string, list<TalkChatMessage>> $result */
+		return new DataResponse($result, Http::STATUS_OK);
+	}
+
+	/**
+	 * @return DataResponse<Http::STATUS_OK, array<string, TalkChatMessage>, array{}>
+	 * @throws CannotReachRemoteException
+	 *
+	 * 200: List of shared objects messages returned
+	 *
+	 * @see \OCA\Talk\Controller\ChatController::getObjectsSharedInRoom()
+	 */
+	public function getObjectsSharedInRoom(Room $room, Participant $participant, string $objectType, int $lastKnownMessageId, int $limit): DataResponse {
+		$proxy = $this->proxy->get(
+			$participant->getAttendee()->getInvitedCloudId(),
+			$participant->getAttendee()->getAccessToken(),
+			$room->getRemoteServer() . '/ocs/v2.php/apps/spreed/api/v1/chat/' . $room->getRemoteToken() . '/share',
+			[
+				'objectType' => $objectType,
+				'lastKnownMessageId' => $lastKnownMessageId,
+				'limit' => $limit,
+			],
+		);
+
+		// We allow "200 OK" and "406 Not Acceptable" here, so that 33 against 32 and before is working well
+		/** @var array<string, TalkChatMessage> $data */
+		$data = $this->proxy->getOCSData($proxy, [Http::STATUS_OK, Http::STATUS_NOT_ACCEPTABLE]);
+		/** @var array<string, TalkChatMessage> $data */
+		$data = $this->userConverter->convertMessages($room, $data);
+
+		return new DataResponse($data, Http::STATUS_OK);
+	}
+
+	/**
+	 * @return DataResponse<Http::STATUS_OK, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND, array{error: 'message'|'until'|'status'}, array{}>
+	 * @throws CannotReachRemoteException
+	 *
+	 * 200: Message was pinned successfully
+	 * 400: Message could not be pinned
+	 * 404: Message was not found
+	 *
+	 * @see \OCA\Talk\Controller\ChatController::pinMessage()
+	 */
+	public function pinMessage(Room $room, Participant $participant, int $messageId, int $pinUntil): DataResponse {
+		$proxy = $this->proxy->post(
+			$participant->getAttendee()->getInvitedCloudId(),
+			$participant->getAttendee()->getAccessToken(),
+			$room->getRemoteServer() . '/ocs/v2.php/apps/spreed/api/v1/chat/' . $room->getRemoteToken() . '/' . $messageId . '/pin',
+			['pinUntil' => $pinUntil]
+		);
+
+		$statusCode = $proxy->getStatusCode();
+		if ($statusCode !== Http::STATUS_OK) {
+			if ($statusCode !== Http::STATUS_NOT_FOUND) {
+				$statusCode = $this->proxy->logUnexpectedStatusCode(__METHOD__, $statusCode);
+				$data = ['error' => 'status'];
+				return new DataResponse($data, $statusCode);
+			}
+			/** @var array{error: 'message'|'until'|'status'} $data */
+			$data = $this->proxy->getOCSData($proxy, [Http::STATUS_NOT_FOUND, Http::STATUS_BAD_REQUEST]);
+			return new DataResponse($data, $statusCode);
+		}
+
+		/** @var ?TalkChatMessageWithParent $data */
+		$data = $this->proxy->getOCSData($proxy, default: null);
+		if (!empty($data)) {
+			/** @var TalkChatMessageWithParent $data */
+			$data = $this->userConverter->convertMessage($room, $data);
+		}
+
+		return new DataResponse($data, Http::STATUS_OK);
+	}
+
+	/**
+	 * @return DataResponse<Http::STATUS_OK, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: 'status'}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array{error: 'message'}, array{}>
+	 * @throws CannotReachRemoteException
+	 *
+	 * 200: Message is not pinned now
+	 * 400: Federation request answered with an unknown status code
+	 * 404: Message was not found
+	 *
+	 * @see \OCA\Talk\Controller\ChatController::unpinMessage()
+	 */
+	public function unpinMessage(Room $room, Participant $participant, int $messageId): DataResponse {
+		$proxy = $this->proxy->delete(
+			$participant->getAttendee()->getInvitedCloudId(),
+			$participant->getAttendee()->getAccessToken(),
+			$room->getRemoteServer() . '/ocs/v2.php/apps/spreed/api/v1/chat/' . $room->getRemoteToken() . '/' . $messageId . '/pin',
+		);
+
+		$statusCode = $proxy->getStatusCode();
+		if ($statusCode !== Http::STATUS_OK) {
+			if ($statusCode !== Http::STATUS_NOT_FOUND) {
+				$statusCode = $this->proxy->logUnexpectedStatusCode(__METHOD__, $statusCode);
+				$data = ['error' => 'status'];
+				return new DataResponse($data, $statusCode);
+			}
+			/** @var array{error: 'message'} $data */
+			$data = $this->proxy->getOCSData($proxy, [Http::STATUS_NOT_FOUND]);
+			return new DataResponse($data, Http::STATUS_NOT_FOUND);
+		}
+
+		/** @var ?TalkChatMessageWithParent $data */
+		$data = $this->proxy->getOCSData($proxy, default: null);
+		if (!empty($data)) {
+			/** @var TalkChatMessageWithParent $data */
+			$data = $this->userConverter->convertMessage($room, $data);
+		}
+
+		return new DataResponse($data, Http::STATUS_OK);
+	}
+
 	/**
 	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>|DataResponse<Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND|Http::STATUS_METHOD_NOT_ALLOWED|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array{error: string}, array{}>
 	 * @throws CannotReachRemoteException
