@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Listener;
@@ -27,6 +12,7 @@ use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Service\ConsentService;
 use OCA\Talk\Service\PollService;
+use OCA\Talk\Service\ScheduledMessageService;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
 use OCP\User\Events\UserDeletedEvent;
@@ -40,9 +26,11 @@ class UserDeletedListener implements IEventListener {
 		private Manager $manager,
 		private PollService $pollService,
 		private ConsentService $consentService,
+		private ScheduledMessageService $messageManager,
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!($event instanceof UserDeletedEvent)) {
 			// Unrelated
@@ -55,5 +43,7 @@ class UserDeletedListener implements IEventListener {
 		$this->pollService->neutralizeDeletedUser(Attendee::ACTOR_USERS, $user->getUID());
 
 		$this->consentService->deleteByActor(Attendee::ACTOR_USERS, $user->getUID());
+
+		$this->messageManager->deleteByActor(Attendee::ACTOR_USERS, $user->getUID());
 	}
 }
