@@ -44,7 +44,7 @@ use OCP\DB\Types;
  * @method bool isArchived()
  * @method void setImportant(bool $important)
  * @method bool isImportant()
- * @method void setSensitive(bool $important)
+ * @method void setSensitive(bool $sensitive)
  * @method bool isSensitive()
  * @internal
  * @method int getPermissions()
@@ -64,6 +64,16 @@ use OCP\DB\Types;
  * @method int getUnreadMessages()
  * @method void setLastAttendeeActivity(int $lastAttendeeActivity)
  * @method int getLastAttendeeActivity()
+ * @method void setHasUnreadThreads(bool $hasUnreadThreads)
+ * @method bool getHasUnreadThreads()
+ * @method void setHasUnreadThreadMentions(bool $hasUnreadThreadMentions)
+ * @method bool getHasUnreadThreadMentions()
+ * @method void setHasUnreadThreadDirects(bool $hasUnreadThreadDirects)
+ * @method bool getHasUnreadThreadDirects()
+ * @method void setHiddenPinnedId(int $hiddenPinnedId)
+ * @method int getHiddenPinnedId()
+ * @method void setHasScheduledMessages(int $scheduledMessages)
+ * @method int getHasScheduledMessages()
  */
 class Attendee extends Entity {
 	public const ACTOR_USERS = 'users';
@@ -92,8 +102,8 @@ class Attendee extends Entity {
 	public const PERMISSIONS_PUBLISH_VIDEO = 32;
 	public const PERMISSIONS_PUBLISH_SCREEN = 64;
 	public const PERMISSIONS_CHAT = 128;
-	public const PERMISSIONS_MAX_DEFAULT = // Max int (when all permissions are granted as default)
-		self::PERMISSIONS_CALL_START
+	public const PERMISSIONS_MAX_DEFAULT // Max int (when all permissions are granted as default)
+		= self::PERMISSIONS_CALL_START
 		| self::PERMISSIONS_CALL_JOIN
 		| self::PERMISSIONS_LOBBY_IGNORE
 		| self::PERMISSIONS_PUBLISH_AUDIO
@@ -133,6 +143,11 @@ class Attendee extends Entity {
 	protected int $state = 0;
 	protected int $unreadMessages = 0;
 	protected int $lastAttendeeActivity = 0;
+	protected bool $hasUnreadThreads = false;
+	protected bool $hasUnreadThreadMentions = false;
+	protected bool $hasUnreadThreadDirects = false;
+	protected int $hiddenPinnedId = 0;
+	protected int $hasScheduledMessages = 0;
 
 	public function __construct() {
 		$this->addType('roomId', Types::BIGINT);
@@ -161,6 +176,12 @@ class Attendee extends Entity {
 		$this->addType('state', Types::SMALLINT);
 		$this->addType('unreadMessages', Types::BIGINT);
 		$this->addType('lastAttendeeActivity', Types::BIGINT);
+		$this->addType('hasUnreadThreads', Types::BOOLEAN);
+		$this->addType('hasUnreadThreadMentions', Types::BOOLEAN);
+		$this->addType('hasUnreadThreadDirects', Types::BOOLEAN);
+		$this->addType('hiddenPinnedId', Types::BIGINT);
+		$this->addType('hasScheduledMessages', Types::INTEGER);
+
 	}
 
 	public function getDisplayName(): string {
