@@ -2,27 +2,13 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2016 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Notification;
 
+use OCA\Circles\CirclesManager;
 use OCA\FederatedFileSharing\AddressHandler;
 use OCA\Talk\AppInfo\Application;
 use OCA\Talk\Chat\ChatManager;
@@ -43,6 +29,7 @@ use OCA\Talk\Room;
 use OCA\Talk\Service\AvatarService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Webinary;
+use OCP\App\IAppManager;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\ICommentsManager;
@@ -60,10 +47,14 @@ use OCP\Notification\IAction;
 use OCP\Notification\IManager as INotificationManager;
 use OCP\Notification\INotification;
 use OCP\Notification\INotifier;
+use OCP\Notification\UnknownNotificationException;
 use OCP\RichObjectStrings\Definitions;
+use OCP\Server;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IManager as IShareManager;
 use OCP\Share\IShare;
+use OCP\Util;
+use Psr\Log\LoggerInterface;
 
 class Notifier implements INotifier {
 
@@ -71,12 +62,17 @@ class Notifier implements INotifier {
 	protected array $rooms = [];
 	/** @var Participant[][] */
 	protected array $participants = [];
+	/** @var array<string, string> */
+	protected array $circleNames = [];
+	/** @var array<string, string> */
+	protected array $circleLinks = [];
 	protected ICommentsManager $commentManager;
 
 	public function __construct(
 		protected IFactory $lFactory,
 		protected IURLGenerator $url,
 		protected Config $config,
+		protected IAppManager $appManager,
 		protected IUserManager $userManager,
 		protected IGroupManager $groupManager,
 		protected GuestManager $guestManager,
@@ -95,6 +91,7 @@ class Notifier implements INotifier {
 		protected BotServerMapper $botServerMapper,
 		protected FederationManager $federationManager,
 		protected ICloudIdManager $cloudIdManager,
+		protected LoggerInterface $logger,
 	) {
 		$this->commentManager = $commentManager;
 	}
@@ -105,6 +102,7 @@ class Notifier implements INotifier {
 	 * @return string
 	 * @since 17.0.0
 	 */
+	#[\Override]
 	public function getID(): string {
 		return 'talk';
 	}
@@ -115,6 +113,7 @@ class Notifier implements INotifier {
 	 * @return string
 	 * @since 17.0.0
 	 */
+	#[\Override]
 	public function getName(): string {
 		return $this->lFactory->get(Application::APP_ID)->t('Talk');
 	}
@@ -147,7 +146,7 @@ class Notifier implements INotifier {
 
 			try {
 				// Before 3.2.3 the id was passed in notifications
-				$room = $this->manager->getRoomById((int) $objectId);
+				$room = $this->manager->getRoomById((int)$objectId);
 				$this->rooms[$objectId] = $room;
 				return $room;
 			} catch (RoomNotFoundException $e) {
@@ -189,12 +188,14 @@ class Notifier implements INotifier {
 	 * @param INotification $notification
 	 * @param string $languageCode The code of the language that should be used to prepare the notification
 	 * @return INotification
-	 * @throws \InvalidArgumentException When the notification was not prepared by a notifier
+	 * @throws AlreadyProcessedException
+	 * @throws UnknownNotificationException
 	 * @since 9.0.0
 	 */
+	#[\Override]
 	public function prepare(INotification $notification, string $languageCode): INotification {
 		if ($notification->getApp() !== Application::APP_ID) {
-			throw new \InvalidArgumentException('Incorrect app');
+			throw new UnknownNotificationException('Incorrect app');
 		}
 
 		if (!($this->notificationManager->isPreparingPushNotification() && $notification->getSubject() === 'call')) {
@@ -252,8 +253,12 @@ class Notifier implements INotifier {
 			->setIcon($this->url->getAbsoluteURL($this->url->imagePath(Application::APP_ID, 'app-dark.svg')))
 			->setLink($this->url->linkToRouteAbsolute('spreed.Page.showCall', ['token' => $room->getToken()]));
 
+		if ($participant instanceof Participant && $this->notificationManager->isPreparingPushNotification()) {
+			$notification->setPriorityNotification($participant->getAttendee()->isImportant());
+		}
+
 		$subject = $notification->getSubject();
-		if ($subject === 'record_file_stored' || $subject === 'transcript_file_stored' || $subject === 'transcript_failed') {
+		if ($subject === 'record_file_stored' || $subject === 'transcript_file_stored' || $subject === 'transcript_failed' || $subject === 'summary_file_stored' || $subject === 'summary_failed') {
 			return $this->parseStoredRecording($notification, $room, $participant, $l);
 		}
 		if ($subject === 'record_file_store_fail') {
@@ -263,9 +268,9 @@ class Notifier implements INotifier {
 			return $this->parseInvitation($notification, $room, $l);
 		}
 		if ($subject === 'call') {
-			if ($participant instanceof Participant &&
-				$room->getLobbyState() !== Webinary::LOBBY_NONE &&
-				!($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+			if ($participant instanceof Participant
+				&& $room->getLobbyState() !== Webinary::LOBBY_NONE
+				&& !($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
 				// User is blocked by the lobby, remove notification
 				throw new AlreadyProcessedException();
 			}
@@ -275,10 +280,10 @@ class Notifier implements INotifier {
 			}
 			return $this->parseCall($notification, $room, $l);
 		}
-		if ($subject === 'reply' || $subject === 'mention' || $subject === 'mention_direct' || $subject === 'mention_group' || $subject === 'mention_all' || $subject === 'chat' || $subject === 'reaction' || $subject === 'reminder') {
-			if ($participant instanceof Participant &&
-				$room->getLobbyState() !== Webinary::LOBBY_NONE &&
-				!($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+		if ($subject === 'reply' || $subject === 'mention' || $subject === 'mention_direct' || $subject === 'mention_group' || $subject === 'mention_team' || $subject === 'mention_all' || $subject === 'chat' || $subject === 'reaction' || $subject === 'reminder') {
+			if ($participant instanceof Participant
+				&& $room->getLobbyState() !== Webinary::LOBBY_NONE
+				&& !($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
 				// User is blocked by the lobby, remove notification
 				throw new AlreadyProcessedException();
 			}
@@ -287,22 +292,14 @@ class Notifier implements INotifier {
 		}
 
 		$this->notificationManager->markProcessed($notification);
-		throw new \InvalidArgumentException('Unknown subject');
-	}
-
-	protected function shortenJsonEncodedMultibyteSave(string $subject, int $dataLength): string {
-		$temp = mb_substr($subject, 0, $dataLength);
-		while (strlen(json_encode($temp)) > $dataLength) {
-			$temp = mb_substr($temp, 0, -5);
-		}
-		return $temp;
+		throw new UnknownNotificationException('Unknown subject');
 	}
 
 	protected function parseStoredRecordingFail(
 		INotification $notification,
 		Room $room,
 		Participant $participant,
-		IL10N $l
+		IL10N $l,
 	): INotification {
 		$notification
 			->setRichSubject(
@@ -313,7 +310,7 @@ class Notifier implements INotifier {
 				[
 					'call' => [
 						'type' => 'call',
-						'id' => $room->getId(),
+						'id' => (string)$room->getId(),
 						'name' => $room->getDisplayName($participant->getAttendee()->getActorId()),
 						'call-type' => $this->getRoomType($room),
 						'icon-url' => $this->avatarService->getAvatarUrl($room),
@@ -327,7 +324,7 @@ class Notifier implements INotifier {
 		INotification $notification,
 		Room $room,
 		Participant $participant,
-		IL10N $l
+		IL10N $l,
 	): INotification {
 		$parameters = $notification->getSubjectParameters();
 		try {
@@ -376,9 +373,15 @@ class Notifier implements INotifier {
 		} elseif ($notification->getSubject() === 'transcript_file_stored') {
 			$subject = $l->t('Transcript now available');
 			$message = $l->t('The transcript for the call in {call} was uploaded to {file}.');
-		} else {
+		} elseif ($notification->getSubject() === 'transcript_failed') {
 			$subject = $l->t('Failed to transcript call recording');
 			$message = $l->t('The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration.');
+		} elseif ($notification->getSubject() === 'summary_file_stored') {
+			$subject = $l->t('Call summary now available');
+			$message = $l->t('The summary for the call in {call} was uploaded to {file}.');
+		} else {
+			$subject = $l->t('Failed to summarize call recording');
+			$message = $l->t('The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration.');
 		}
 
 		$notification
@@ -388,21 +391,21 @@ class Notifier implements INotifier {
 				[
 					'call' => [
 						'type' => 'call',
-						'id' => $room->getId(),
+						'id' => (string)$room->getId(),
 						'name' => $room->getDisplayName($participant->getAttendee()->getActorId()),
 						'call-type' => $this->getRoomType($room),
 						'icon-url' => $this->avatarService->getAvatarUrl($room),
 					],
 					'file' => [
 						'type' => 'file',
-						'id' => $file->getId(),
+						'id' => (string)$file->getId(),
 						'name' => $file->getName(),
-						'path' => $path,
+						'path' => (string)$path,
 						'link' => $this->url->linkToRouteAbsolute('files.viewcontroller.showFile', ['fileid' => $file->getId()]),
 					],
 				]);
 
-		if ($notification->getSubject() !== 'transcript_failed') {
+		if ($notification->getSubject() !== 'transcript_failed' && $notification->getSubject() !== 'summary_failed') {
 			$notification->addParsedAction($shareAction);
 			$notification->addParsedAction($dismissAction);
 		}
@@ -414,7 +417,7 @@ class Notifier implements INotifier {
 		$subjectParameters = $notification->getSubjectParameters();
 
 		try {
-			$invite = $this->federationManager->getRemoteShareById((int) $notification->getObjectId());
+			$invite = $this->federationManager->getRemoteShareById((int)$notification->getObjectId());
 			if ($invite->getUserId() !== $notification->getUser()) {
 				throw new AlreadyProcessedException();
 			}
@@ -454,7 +457,7 @@ class Notifier implements INotifier {
 		$acceptAction->setParsedLabel($l->t('Accept'));
 		$acceptAction->setLink($this->url->linkToOCSRouteAbsolute(
 			'spreed.Federation.acceptShare',
-			['apiVersion' => 'v1', 'id' => (int) $notification->getObjectId()]
+			['apiVersion' => 'v1', 'id' => (int)$notification->getObjectId()]
 		), IAction::TYPE_POST);
 		$acceptAction->setPrimary(true);
 		$notification->addParsedAction($acceptAction);
@@ -463,7 +466,7 @@ class Notifier implements INotifier {
 		$declineAction->setParsedLabel($l->t('Decline'));
 		$declineAction->setLink($this->url->linkToOCSRouteAbsolute(
 			'spreed.Federation.rejectShare',
-			['apiVersion' => 'v1', 'id' => (int) $notification->getObjectId()]
+			['apiVersion' => 'v1', 'id' => (int)$notification->getObjectId()]
 		), IAction::TYPE_DELETE);
 		$notification->addParsedAction($declineAction);
 
@@ -480,11 +483,11 @@ class Notifier implements INotifier {
 	 * @param IL10N $l
 	 * @return INotification
 	 * @throws AlreadyProcessedException
-	 * @throws \InvalidArgumentException
+	 * @throws UnknownNotificationException
 	 */
 	protected function parseChatMessage(INotification $notification, Room $room, Participant $participant, IL10N $l): INotification {
 		if ($notification->getObjectType() !== 'chat' && $notification->getObjectType() !== 'reminder') {
-			throw new \InvalidArgumentException('Unknown object type');
+			throw new UnknownNotificationException('Unknown object type');
 		}
 
 		$messageParameters = $notification->getMessageParameters();
@@ -501,19 +504,25 @@ class Notifier implements INotifier {
 				 * @see Listener::markReactionNotificationsRead()
 				 */
 				&& $notification->getSubject() !== 'reaction'
-				&& ((int) $messageParameters['commentId']) <= $participant->getAttendee()->getLastReadMessage()) {
+				&& ((int)$messageParameters['commentId']) <= $participant->getAttendee()->getLastReadMessage()) {
 				// Mark notifications of messages that are read as processed
 				throw new AlreadyProcessedException();
 			}
 
 			try {
 				$comment = $this->commentManager->get($messageParameters['commentId']);
-			} catch (NotFoundException $e) {
+			} catch (NotFoundException) {
+				throw new AlreadyProcessedException();
+			}
+
+			if ($comment->getObjectType() !== 'chat'
+				|| $room->getId() !== (int)$comment->getObjectId()) {
+				$this->logger->warning('Ignoring ' . $notification->getSubject() . ' notification for user ' . $notification->getUser() . ' as messages #' . $comment->getId() . ' could not be found for conversation ' . $room->getToken());
 				throw new AlreadyProcessedException();
 			}
 
 			$message = $this->messageParser->createMessage($room, $participant, $comment, $l);
-			$this->messageParser->parseMessage($message);
+			$this->messageParser->parseMessage($message, true);
 
 			if (!$message->getVisibility()) {
 				throw new AlreadyProcessedException();
@@ -580,14 +589,21 @@ class Notifier implements INotifier {
 
 		$richSubjectCall = [
 			'type' => 'call',
-			'id' => $room->getId(),
+			'id' => (string)$room->getId(),
 			'name' => $room->getDisplayName($notification->getUser()),
 			'call-type' => $this->getRoomType($room),
 			'icon-url' => $this->avatarService->getAvatarUrl($room),
 		];
 
 		// Set the link to the specific message
-		$notification->setLink($this->url->linkToRouteAbsolute('spreed.Page.showCall', ['token' => $room->getToken()]) . '#message_' . $message->getMessageId());
+		$urlParams = [
+			'token' => $room->getToken(),
+			'_fragment' => 'message_' . $message->getMessageId(),
+		];
+		if (isset($messageParameters['threadId'])) {
+			$urlParams['threadId'] = $messageParameters['threadId'];
+		}
+		$notification->setLink($this->url->linkToRouteAbsolute('spreed.Page.showCall', $urlParams));
 
 		$now = $this->timeFactory->getDateTime();
 		$expireDate = $message->getExpirationDateTime();
@@ -610,12 +626,15 @@ class Notifier implements INotifier {
 		}
 
 		$parsedMessage = str_replace($placeholders, $replacements, $message->getMessage());
-		if (!$this->notificationManager->isPreparingPushNotification()) {
+		if (!$this->notificationManager->isPreparingPushNotification() && !$participant->getAttendee()->isSensitive()) {
 			$notification->setParsedMessage($parsedMessage);
 			$notification->setRichMessage($message->getMessage(), $message->getMessageParameters());
 
 			// Forward the message ID as well to the clients, so they can quote the message on replies
 			$notification->setObject($notification->getObjectType(), $notification->getObjectId() . '/' . $message->getMessageId());
+			if (isset($messageParameters['threadId'])) {
+				$notification->setObject($notification->getObjectType(), $notification->getObjectId() . '/' . $messageParameters['threadId']);
+			}
 		}
 
 		$richSubjectParameters = [
@@ -623,14 +642,51 @@ class Notifier implements INotifier {
 			'call' => $richSubjectCall,
 		];
 
-		if ($this->notificationManager->isPreparingPushNotification()) {
-			$shortenMessage = $this->shortenJsonEncodedMultibyteSave($parsedMessage, 100);
+		if ($participant->getAttendee()->isSensitive()) {
+			// Prevent message preview and conversation name in sensitive conversations
+
+			if ($this->notificationManager->isPreparingPushNotification()) {
+				$translatedPrivateConversation = $l->t('Private conversation');
+
+				if ($notification->getSubject() === 'reaction') {
+					// TRANSLATORS Someone reacted in a private conversation
+					$subject = $translatedPrivateConversation . "\n" . $l->t('Someone reacted');
+				} elseif ($notification->getSubject() === 'chat') {
+					// TRANSLATORS You received a new message in a private conversation
+					$subject = $translatedPrivateConversation . "\n" . $l->t('New message');
+				} elseif ($notification->getSubject() === 'reminder') {
+					// TRANSLATORS Reminder for a message in a private conversation
+					$subject = $translatedPrivateConversation . "\n" . $l->t('Reminder');
+				} elseif (str_starts_with($notification->getSubject(), 'mention_')) {
+					// TRANSLATORS Someone mentioned you in a private conversation
+					$subject = $translatedPrivateConversation . "\n" . $l->t('Someone mentioned you');
+				} else {
+					// TRANSLATORS There's a notification in a private conversation
+					$subject = $translatedPrivateConversation . "\n" . $l->t('Notification');
+				}
+			} else {
+				if ($notification->getSubject() === 'reaction') {
+					$subject = $l->t('Someone reacted in a private conversation');
+				} elseif ($notification->getSubject() === 'chat') {
+					$subject = $l->t('You received a message in a private conversation');
+				} elseif ($notification->getSubject() === 'reminder') {
+					$subject = $l->t('Reminder in a private conversation');
+				} elseif (str_starts_with($notification->getSubject(), 'mention_')) {
+					$subject = $l->t('Someone mentioned you in a private conversation');
+				} else {
+					$subject = $l->t('Notification in a private conversation');
+				}
+			}
+
+			$richSubjectParameters = [];
+		} elseif ($this->notificationManager->isPreparingPushNotification()) {
+			$shortenMessage = Util::shortenMultibyteString($parsedMessage, 100);
 			if ($shortenMessage !== $parsedMessage) {
 				$shortenMessage .= '…';
 			}
 			$richSubjectParameters['message'] = [
 				'type' => 'highlight',
-				'id' => $message->getMessageId(),
+				'id' => (string)$message->getMessageId(),
 				'name' => $shortenMessage,
 			];
 			if ($notification->getSubject() === 'reminder') {
@@ -648,7 +704,7 @@ class Notifier implements INotifier {
 					$subject = $l->t('Reminder: Deleted user in {call}') . "\n{message}";
 				} else {
 					try {
-						$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorId());
+						$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorType(), $message->getActorId());
 						// TRANSLATORS Reminder for a message from a guest in conversation {call}
 						$subject = $l->t('Reminder: {guest} (guest) in {call}') . "\n{message}";
 					} catch (ParticipantNotFoundException $e) {
@@ -671,7 +727,7 @@ class Notifier implements INotifier {
 					$subject = $l->t('Deleted user reacted with {reaction} in {call}') . "\n{message}";
 				} else {
 					try {
-						$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorId());
+						$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorType(), $message->getActorId());
 						$subject = $l->t('{guest} (guest) reacted with {reaction} in {call}') . "\n{message}";
 					} catch (ParticipantNotFoundException $e) {
 						$subject = $l->t('Guest reacted with {reaction} in {call}') . "\n{message}";
@@ -686,7 +742,7 @@ class Notifier implements INotifier {
 					$subject = $l->t('Deleted user in {call}') . "\n{message}";
 				} else {
 					try {
-						$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorId());
+						$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorType(), $message->getActorId());
 						$subject = $l->t('{guest} (guest) in {call}') . "\n{message}";
 					} catch (ParticipantNotFoundException $e) {
 						$subject = $l->t('Guest in {call}') . "\n{message}";
@@ -702,7 +758,7 @@ class Notifier implements INotifier {
 				$subject = $l->t('A deleted user sent a message in conversation {call}');
 			} else {
 				try {
-					$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorId());
+					$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorType(), $message->getActorId());
 					$subject = $l->t('{guest} (guest) sent a message in conversation {call}');
 				} catch (ParticipantNotFoundException $e) {
 					$subject = $l->t('A guest sent a message in conversation {call}');
@@ -717,7 +773,7 @@ class Notifier implements INotifier {
 				$subject = $l->t('A deleted user replied to your message in conversation {call}');
 			} else {
 				try {
-					$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorId());
+					$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorType(), $message->getActorId());
 					$subject = $l->t('{guest} (guest) replied to your message in conversation {call}');
 				} catch (ParticipantNotFoundException $e) {
 					$subject = $l->t('A guest replied to your message in conversation {call}');
@@ -742,7 +798,7 @@ class Notifier implements INotifier {
 				$subject = $l->t('Reminder: A deleted user in conversation {call}');
 			} else {
 				try {
-					$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorId());
+					$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorType(), $message->getActorId());
 					$subject = $l->t('Reminder: {guest} (guest) in conversation {call}');
 				} catch (ParticipantNotFoundException) {
 					$subject = $l->t('Reminder: A guest in conversation {call}');
@@ -763,7 +819,7 @@ class Notifier implements INotifier {
 				$subject = $l->t('A deleted user reacted with {reaction} to your message in conversation {call}');
 			} else {
 				try {
-					$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorId());
+					$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorType(), $message->getActorId());
 					$subject = $l->t('{guest} (guest) reacted with {reaction} to your message in conversation {call}');
 				} catch (ParticipantNotFoundException $e) {
 					$subject = $l->t('A guest reacted with {reaction} to your message in conversation {call}');
@@ -781,6 +837,9 @@ class Notifier implements INotifier {
 				];
 
 				$subject = $l->t('{user} mentioned group {group} in conversation {call}');
+			} elseif ($notification->getSubject() === 'mention_team') {
+				$richSubjectParameters['team'] = $this->getCircle($subjectParameters['sourceId']);
+				$subject = $l->t('{user} mentioned team {team} in conversation {call}');
 			} elseif ($notification->getSubject() === 'mention_all') {
 				$subject = $l->t('{user} mentioned everyone in conversation {call}');
 			} else {
@@ -796,6 +855,9 @@ class Notifier implements INotifier {
 				];
 
 				$subject = $l->t('A deleted user mentioned group {group} in conversation {call}');
+			} elseif ($notification->getSubject() === 'mention_team') {
+				$richSubjectParameters['team'] = $this->getCircle($subjectParameters['sourceId']);
+				$subject = $l->t('A deleted user mentioned team {team} in conversation {call}');
 			} elseif ($notification->getSubject() === 'mention_all') {
 				$subject = $l->t('A deleted user mentioned everyone in conversation {call}');
 			} else {
@@ -803,7 +865,7 @@ class Notifier implements INotifier {
 			}
 		} else {
 			try {
-				$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorId());
+				$richSubjectParameters['guest'] = $this->getGuestParameter($room, $message->getActorType(), $message->getActorId());
 				if ($notification->getSubject() === 'mention_group') {
 					$groupName = $this->groupManager->getDisplayName($subjectParameters['sourceId']) ?? $subjectParameters['sourceId'];
 					$richSubjectParameters['group'] = [
@@ -813,6 +875,9 @@ class Notifier implements INotifier {
 					];
 
 					$subject = $l->t('{guest} (guest) mentioned group {group} in conversation {call}');
+				} elseif ($notification->getSubject() === 'mention_team') {
+					$richSubjectParameters['team'] = $this->getCircle($subjectParameters['sourceId']);
+					$subject = $l->t('{guest} (guest) mentioned team {team} in conversation {call}');
 				} elseif ($notification->getSubject() === 'mention_all') {
 					$subject = $l->t('{guest} (guest) mentioned everyone in conversation {call}');
 				} else {
@@ -828,6 +893,9 @@ class Notifier implements INotifier {
 					];
 
 					$subject = $l->t('A guest mentioned group {group} in conversation {call}');
+				} elseif ($notification->getSubject() === 'mention_team') {
+					$richSubjectParameters['team'] = $this->getCircle($subjectParameters['sourceId']);
+					$subject = $l->t('A guest mentioned team {team} in conversation {call}');
 				} elseif ($notification->getSubject() === 'mention_all') {
 					$subject = $l->t('A guest mentioned everyone in conversation {call}');
 				} else {
@@ -859,7 +927,7 @@ class Notifier implements INotifier {
 			$notification = $this->addActionButton($notification, 'chat_view', $l->t('View chat'), false);
 		}
 
-		if ($richSubjectParameters['user'] === null) {
+		if (array_key_exists('user', $richSubjectParameters) && $richSubjectParameters['user'] === null) {
 			unset($richSubjectParameters['user']);
 		}
 
@@ -877,12 +945,17 @@ class Notifier implements INotifier {
 
 	/**
 	 * @param Room $room
+	 * @param Attendee::ACTOR_* $actorType
 	 * @param string $actorId
 	 * @return array
 	 * @throws ParticipantNotFoundException
 	 */
-	protected function getGuestParameter(Room $room, string $actorId): array {
-		$participant = $this->participantService->getParticipantByActor($room, Attendee::ACTOR_GUESTS, $actorId);
+	protected function getGuestParameter(Room $room, string $actorType, string $actorId): array {
+		if (!in_array($actorType, [Attendee::ACTOR_GUESTS, Attendee::ACTOR_EMAILS], true)) {
+			throw new ParticipantNotFoundException('Not a guest actor type');
+		}
+
+		$participant = $this->participantService->getParticipantByActor($room, $actorType, $actorId);
 		$name = $participant->getAttendee()->getDisplayName();
 		if (trim($name) === '') {
 			throw new ParticipantNotFoundException('Empty name');
@@ -920,12 +993,12 @@ class Notifier implements INotifier {
 	 * @param Room $room
 	 * @param IL10N $l
 	 * @return INotification
-	 * @throws \InvalidArgumentException
 	 * @throws AlreadyProcessedException
+	 * @throws UnknownNotificationException
 	 */
 	protected function parseInvitation(INotification $notification, Room $room, IL10N $l): INotification {
 		if ($notification->getObjectType() !== 'room') {
-			throw new \InvalidArgumentException('Unknown object type');
+			throw new UnknownNotificationException('Unknown object type');
 		}
 
 		$parameters = $notification->getSubjectParameters();
@@ -937,33 +1010,7 @@ class Notifier implements INotifier {
 		}
 
 		$roomName = $room->getDisplayName($notification->getUser());
-		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
-			$subject = $l->t('{user} invited you to a private conversation');
-			if ($this->participantService->hasActiveSessionsInCall($room)) {
-				$notification = $this->addActionButton($notification, 'call_view', $l->t('Join call'), true, true);
-			} else {
-				$notification = $this->addActionButton($notification, 'chat_view', $l->t('View chat'), false);
-			}
-
-			$notification
-				->setParsedSubject(str_replace('{user}', $userDisplayName, $subject))
-				->setRichSubject(
-					$subject, [
-						'user' => [
-							'type' => 'user',
-							'id' => $uid,
-							'name' => $userDisplayName,
-						],
-						'call' => [
-							'type' => 'call',
-							'id' => $room->getId(),
-							'name' => $roomName,
-							'call-type' => $this->getRoomType($room),
-							'icon-url' => $this->avatarService->getAvatarUrl($room),
-						],
-					]
-				);
-		} elseif (\in_array($room->getType(), [Room::TYPE_GROUP, Room::TYPE_PUBLIC], true)) {
+		if (\in_array($room->getType(), [Room::TYPE_GROUP, Room::TYPE_PUBLIC], true)) {
 			$subject = $l->t('{user} invited you to a group conversation: {call}');
 			if ($this->participantService->hasActiveSessionsInCall($room)) {
 				$notification = $this->addActionButton($notification, 'call_view', $l->t('Join call'), true, true);
@@ -982,7 +1029,7 @@ class Notifier implements INotifier {
 						],
 						'call' => [
 							'type' => 'call',
-							'id' => $room->getId(),
+							'id' => (string)$room->getId(),
 							'name' => $roomName,
 							'call-type' => $this->getRoomType($room),
 							'icon-url' => $this->avatarService->getAvatarUrl($room),
@@ -1001,18 +1048,18 @@ class Notifier implements INotifier {
 	 * @param Room $room
 	 * @param IL10N $l
 	 * @return INotification
-	 * @throws \InvalidArgumentException
 	 * @throws AlreadyProcessedException
+	 * @throws UnknownNotificationException
 	 */
 	protected function parseCall(INotification $notification, Room $room, IL10N $l): INotification {
 		if ($notification->getObjectType() !== 'call') {
-			throw new \InvalidArgumentException('Unknown object type');
+			throw new UnknownNotificationException('Unknown object type');
 		}
 
 		$roomName = $room->getDisplayName($notification->getUser());
 		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 			$parameters = $notification->getSubjectParameters();
-			$calleeId = $parameters['callee'];
+			$calleeId = $parameters['callee']; // TODO can be null on federated conversations, so needs to be changed once we have federated 1-1
 			$userDisplayName = $this->userManager->getDisplayName($calleeId);
 			if ($userDisplayName !== null) {
 				if ($this->notificationManager->isPreparingPushNotification() || $this->participantService->hasActiveSessionsInCall($room)) {
@@ -1034,7 +1081,7 @@ class Notifier implements INotifier {
 							],
 							'call' => [
 								'type' => 'call',
-								'id' => $room->getId(),
+								'id' => (string)$room->getId(),
 								'name' => $roomName,
 								'call-type' => $this->getRoomType($room),
 								'icon-url' => $this->avatarService->getAvatarUrl($room),
@@ -1044,8 +1091,37 @@ class Notifier implements INotifier {
 			} else {
 				throw new AlreadyProcessedException();
 			}
+		} elseif ($room->getObjectId() === Room::OBJECT_ID_PHONE_INCOMING
+			&& in_array($room->getObjectType(), [Room::OBJECT_TYPE_PHONE_PERSIST, Room::OBJECT_TYPE_PHONE_TEMPORARY, Room::OBJECT_TYPE_PHONE_LEGACY], true)) {
+			if ($this->notificationManager->isPreparingPushNotification()
+				|| (!$room->isFederatedConversation() && $this->participantService->hasActiveSessionsInCall($room))
+				|| ($room->isFederatedConversation() && $room->getActiveSince())
+			) {
+				$notification = $this->addActionButton($notification, 'call_view', $l->t('Accept call'), true, true);
+				$subject = $l->t('Incoming phone call from {call}');
+			} else {
+				$notification = $this->addActionButton($notification, 'chat_view', $l->t('View chat'), false);
+				$subject = $l->t('You missed a phone call from {call}');
+			}
+
+			$notification
+				->setParsedSubject(str_replace('{call}', $roomName, $subject))
+				->setRichSubject(
+					$subject, [
+						'call' => [
+							'type' => 'call',
+							'id' => (string)$room->getId(),
+							'name' => $roomName,
+							'call-type' => $this->getRoomType($room),
+							'icon-url' => $this->avatarService->getAvatarUrl($room),
+						],
+					]
+				);
 		} elseif (\in_array($room->getType(), [Room::TYPE_GROUP, Room::TYPE_PUBLIC], true)) {
-			if ($this->notificationManager->isPreparingPushNotification() || $this->participantService->hasActiveSessionsInCall($room)) {
+			if ($this->notificationManager->isPreparingPushNotification()
+				|| (!$room->isFederatedConversation() && $this->participantService->hasActiveSessionsInCall($room))
+				|| ($room->isFederatedConversation() && $room->getActiveSince())
+			) {
 				$notification = $this->addActionButton($notification, 'call_view', $l->t('Join call'), true, true);
 				$subject = $l->t('A group call has started in {call}');
 			} else {
@@ -1059,7 +1135,7 @@ class Notifier implements INotifier {
 					$subject, [
 						'call' => [
 							'type' => 'call',
-							'id' => $room->getId(),
+							'id' => (string)$room->getId(),
 							'name' => $roomName,
 							'call-type' => $this->getRoomType($room),
 							'icon-url' => $this->avatarService->getAvatarUrl($room),
@@ -1078,12 +1154,12 @@ class Notifier implements INotifier {
 	 * @param Room $room
 	 * @param IL10N $l
 	 * @return INotification
-	 * @throws \InvalidArgumentException
 	 * @throws AlreadyProcessedException
+	 * @throws UnknownNotificationException
 	 */
 	protected function parsePasswordRequest(INotification $notification, Room $room, IL10N $l): INotification {
 		if ($notification->getObjectType() !== 'call') {
-			throw new \InvalidArgumentException('Unknown object type');
+			throw new UnknownNotificationException('Unknown object type');
 		}
 
 		try {
@@ -1095,7 +1171,7 @@ class Notifier implements INotifier {
 		try {
 			$file = [
 				'type' => 'highlight',
-				'id' => $share->getNodeId(),
+				'id' => (string)$share->getNodeId(),
 				'name' => $share->getNode()->getName(),
 			];
 		} catch (\OCP\Files\NotFoundException $e) {
@@ -1160,6 +1236,9 @@ class Notifier implements INotifier {
 		return $notification;
 	}
 
+	/**
+	 * @throws UnknownNotificationException
+	 */
 	protected function parseHostedSignalingServer(INotification $notification, IL10N $l): INotification {
 		$action = $notification->createAction();
 		$action->setLabel('open_settings')
@@ -1192,7 +1271,7 @@ class Notifier implements INotifier {
 				];
 				break;
 			default:
-				throw new \InvalidArgumentException('Unknown subject');
+				throw new UnknownNotificationException('Unknown subject');
 		}
 
 		return $notification
@@ -1243,4 +1322,47 @@ class Notifier implements INotifier {
 
 		return $notification;
 	}
+
+	protected function getCircle(string $circleId): array {
+		if (!$this->appManager->isEnabledForUser('circles')) {
+			return [
+				'type' => 'highlight',
+				'id' => $circleId,
+				'name' => $circleId,
+			];
+		}
+
+		if (!isset($this->circleNames[$circleId])) {
+			$this->loadCircleDetails($circleId);
+		}
+
+		if (!isset($this->circleNames[$circleId])) {
+			return [
+				'type' => 'highlight',
+				'id' => $circleId,
+				'name' => $circleId,
+			];
+		}
+
+		return [
+			'type' => 'circle',
+			'id' => $circleId,
+			'name' => $this->circleNames[$circleId],
+			'link' => $this->circleLinks[$circleId],
+		];
+	}
+
+	protected function loadCircleDetails(string $circleId): void {
+		try {
+			$circlesManager = Server::get(CirclesManager::class);
+			$circlesManager->startSuperSession();
+			$circle = $circlesManager->getCircle($circleId);
+
+			$this->circleNames[$circleId] = $circle->getDisplayName();
+			$this->circleLinks[$circleId] = $circle->getUrl();
+		} catch (\Exception) {
+		} finally {
+			$circlesManager?->stopSession();
+		}
+	}
 }
