@@ -10,15 +10,14 @@ declare(strict_types=1);
 namespace OCA\Talk\Service;
 
 use InvalidArgumentException;
-use OC\Files\Filesystem;
 use OCA\Talk\Room;
 use OCP\Files\IAppData;
+use OCP\Files\IFilenameValidator;
 use OCP\Files\NotFoundException;
 use OCP\Files\SimpleFS\InMemoryFile;
 use OCP\Files\SimpleFS\ISimpleFile;
 use OCP\Files\SimpleFS\ISimpleFolder;
 use OCP\IAvatarManager;
-use OCP\IEmojiHelper;
 use OCP\IL10N;
 use OCP\IURLGenerator;
 use OCP\IUser;
@@ -36,7 +35,8 @@ class AvatarService {
 		private ISecureRandom $random,
 		private RoomService $roomService,
 		private IAvatarManager $avatarManager,
-		private IEmojiHelper $emojiHelper,
+		private EmojiService $emojiService,
+		private IFilenameValidator $filenameValidator,
 	) {
 	}
 
@@ -49,11 +49,7 @@ class AvatarService {
 			throw new InvalidArgumentException($this->l->t('No image file provided'));
 		}
 
-		if (
-			$file['error'] !== 0 ||
-			!is_uploaded_file($file['tmp_name']) ||
-			Filesystem::isFileBlacklisted($file['tmp_name'])
-		) {
+		if ($file['error'] !== 0 || !is_uploaded_file($file['tmp_name'])) {
 			throw new InvalidArgumentException($this->l->t('Invalid file provided'));
 		}
 		if ($file['size'] > 20 * 1024 * 1024) {
@@ -61,8 +57,9 @@ class AvatarService {
 		}
 
 		$content = file_get_contents($file['tmp_name']);
+		// noopengrep: php.lang.security.unlink-use.unlink-use
 		unlink($file['tmp_name']);
-		$image = new \OC_Image();
+		$image = new \OCP\Image();
 		$image->loadFromData($content);
 		$image->readExif($content);
 		$this->setAvatar($room, $image);
@@ -73,7 +70,7 @@ class AvatarService {
 			throw new InvalidArgumentException($this->l->t('One-to-one rooms always need to show the other users avatar'));
 		}
 
-		if ($this->getFirstCombinedEmoji($emoji) !== $emoji) {
+		if ($this->emojiService->getFirstCombinedEmoji($emoji) !== $emoji) {
 			throw new InvalidArgumentException($this->l->t('Invalid emoji character'));
 		}
 
@@ -98,7 +95,7 @@ class AvatarService {
 		$this->roomService->setAvatar($room, $avatarName);
 	}
 
-	public function setAvatar(Room $room, \OC_Image $image): void {
+	public function setAvatar(Room $room, \OCP\Image $image): void {
 		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 			throw new InvalidArgumentException($this->l->t('One-to-one rooms always need to show the other users avatar'));
 		}
@@ -207,12 +204,11 @@ class AvatarService {
 				}
 			}
 		}
-		if ($this->emojiHelper->doesPlatformSupportEmoji() && $this->emojiHelper->isValidSingleEmoji(mb_substr($room->getName(), 0, 1))) {
+		if ($this->emojiService->isValidSingleEmoji(mb_substr($room->getName(), 0, 1))) {
 			return new InMemoryFile(
 				$token,
 				$this->getEmojiAvatar(
-					$this->getFirstCombinedEmoji(
-						$room->getName()),
+					$this->emojiService->getFirstCombinedEmoji($room->getName()),
 					$darkTheme ? self::THEMING_DARK_BACKGROUND : self::THEMING_BRIGHT_BACKGROUND
 				)
 			);
@@ -251,26 +247,6 @@ class AvatarService {
 		], $this->svgTemplate);
 	}
 
-	/**
-	 * Get the first combined full emoji (including gender, skin tone, job, …)
-	 *
-	 * @param string $roomName
-	 * @param int $length
-	 * @return string
-	 */
-	protected function getFirstCombinedEmoji(string $roomName, int $length = 0): string {
-		if (!$this->emojiHelper->doesPlatformSupportEmoji() || mb_strlen($roomName) === $length) {
-			return '';
-		}
-
-		$attempt = mb_substr($roomName, 0, $length + 1);
-		if ($this->emojiHelper->isValidSingleEmoji($attempt)) {
-			$longerAttempt = $this->getFirstCombinedEmoji($roomName, $length + 1);
-			return $longerAttempt ?: $attempt;
-		}
-		return '';
-	}
-
 	public function isCustomAvatar(Room $room): bool {
 		return $room->getAvatar() !== '';
 	}
@@ -289,9 +265,12 @@ class AvatarService {
 		if ($room->getObjectType() === Room::OBJECT_TYPE_EMAIL) {
 			return __DIR__ . '/../../img/icon-conversation-mail-' . $colorTone . '.svg';
 		}
-		if ($room->getObjectType() === Room::OBJECT_TYPE_PHONE) {
+		if (in_array($room->getObjectType(), [Room::OBJECT_TYPE_PHONE_PERSIST, Room::OBJECT_TYPE_PHONE_TEMPORARY, Room::OBJECT_TYPE_PHONE_LEGACY], true)) {
 			return __DIR__ . '/../../img/icon-conversation-phone-' . $colorTone . '.svg';
 		}
+		if ($room->getObjectType() === Room::OBJECT_TYPE_EVENT) {
+			return __DIR__ . '/../../img/icon-conversation-event-' . $colorTone . '.svg';
+		}
 		if ($room->isFederatedConversation()) {
 			return __DIR__ . '/../../img/icon-conversation-federation-' . $colorTone . '.svg';
 		}
@@ -335,8 +314,8 @@ class AvatarService {
 			[$version] = explode('.', $avatarVersion);
 			return $version;
 		}
-		if ($this->emojiHelper->doesPlatformSupportEmoji() && $this->emojiHelper->isValidSingleEmoji(mb_substr($room->getName(), 0, 1))) {
-			return substr(md5($this->getEmojiAvatar($this->getFirstCombinedEmoji($room->getName()), self::THEMING_BRIGHT_BACKGROUND)), 0, 8);
+		if ($this->emojiService->isValidSingleEmoji(mb_substr($room->getName(), 0, 1))) {
+			return substr(md5($this->getEmojiAvatar($this->emojiService->getFirstCombinedEmoji($room->getName()), self::THEMING_BRIGHT_BACKGROUND)), 0, 8);
 		}
 		$avatarPath = $this->getAvatarPath($room);
 		return substr(md5($avatarPath), 0, 8);
