@@ -14,6 +14,7 @@ use OCA\Talk\Federation\Proxy\TalkV1\UserConverter;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\BreakoutRoom;
 use OCA\Talk\Model\Session;
+use OCA\Talk\Model\Thread;
 use OCA\Talk\Participant;
 use OCA\Talk\ResponseDefinitions;
 use OCA\Talk\Room;
@@ -51,6 +52,7 @@ class RoomFormatter {
 		protected UserConverter $userConverter,
 		protected IL10N $l10n,
 		protected ?string $userId,
+		protected ThreadService $threadService,
 	) {
 	}
 
@@ -66,6 +68,8 @@ class RoomFormatter {
 		bool $isSIPBridgeRequest = false,
 		bool $isListingBreakoutRooms = false,
 		bool $skipLastMessage = false,
+		?Thread $thread = null,
+		bool $isThreadInfoComplete = false,
 	): array {
 		return $this->formatRoomV4(
 			$responseFormat,
@@ -76,6 +80,8 @@ class RoomFormatter {
 			$isSIPBridgeRequest,
 			$isListingBreakoutRooms,
 			$skipLastMessage,
+			$thread,
+			$isThreadInfoComplete,
 		);
 	}
 
@@ -92,6 +98,8 @@ class RoomFormatter {
 		bool $isSIPBridgeRequest,
 		bool $isListingBreakoutRooms,
 		bool $skipLastMessage,
+		?Thread $thread = null,
+		bool $isThreadInfoComplete = false,
 	): array {
 		$roomData = [
 			'id' => $room->getId(),
@@ -144,9 +152,13 @@ class RoomFormatter {
 			'breakoutRoomStatus' => BreakoutRoom::STATUS_STOPPED,
 			'recordingConsent' => $this->talkConfig->recordingConsentRequired() === RecordingService::CONSENT_REQUIRED_OPTIONAL ? $room->getRecordingConsent() : $this->talkConfig->recordingConsentRequired(),
 			'mentionPermissions' => Room::MENTION_PERMISSIONS_EVERYONE,
+			'liveTranscriptionLanguageId' => '',
+			'lastPinnedId' => 0,
+			'hiddenPinnedId' => 0,
 			'isArchived' => false,
 			'isImportant' => false,
 			'isSensitive' => false,
+			'hasScheduledMessages' => 0,
 		];
 
 		if ($room->isFederatedConversation()) {
@@ -230,9 +242,12 @@ class RoomFormatter {
 			'breakoutRoomMode' => $room->getBreakoutRoomMode(),
 			'breakoutRoomStatus' => $room->getBreakoutRoomStatus(),
 			'mentionPermissions' => $room->getMentionPermissions(),
+			'liveTranscriptionLanguageId' => $room->getLiveTranscriptionLanguageId(),
 			'isArchived' => $attendee->isArchived(),
 			'isImportant' => $attendee->isImportant(),
 			'isSensitive' => $attendee->isSensitive(),
+			'lastPinnedId' => $room->getLastPinnedId(),
+			'hiddenPinnedId' => $attendee->getHiddenPinnedId(),
 		]);
 
 		if ($room->isFederatedConversation()) {
@@ -274,7 +289,7 @@ class RoomFormatter {
 			} else {
 				$adminSetting = (int)$this->serverConfig->getAppValue('spreed', 'default_group_notification', (string)Participant::NOTIFY_DEFAULT);
 				if ($adminSetting === Participant::NOTIFY_DEFAULT) {
-					$roomData['notificationLevel'] = Participant::NOTIFY_MENTION;
+					$roomData['notificationLevel'] = Participant::NOTIFY_ALWAYS;
 				} else {
 					$roomData['notificationLevel'] = $adminSetting;
 				}
@@ -310,8 +325,8 @@ class RoomFormatter {
 
 				$lastMention = $attendee->getLastMentionMessage();
 				$lastMentionDirect = $attendee->getLastMentionDirect();
-				$roomData['unreadMention'] = $lastMention !== 0 && $lastReadMessage < $lastMention;
-				$roomData['unreadMentionDirect'] = $lastMentionDirect !== 0 && $lastReadMessage < $lastMentionDirect;
+				$roomData['unreadMention'] = $roomData['unreadMessages'] !== 0 && $lastMention !== 0 && $lastReadMessage < $lastMention;
+				$roomData['unreadMentionDirect'] = $roomData['unreadMessages'] !== 0 && $lastMentionDirect !== 0 && $lastReadMessage < $lastMentionDirect;
 				$roomData['lastReadMessage'] = $lastReadMessage;
 
 				$roomData['canDeleteConversation'] = $room->getType() !== Room::TYPE_ONE_TO_ONE
@@ -325,12 +340,13 @@ class RoomFormatter {
 					$roomData['canLeaveConversation'] = false;
 				}
 
-				$roomData['canEnableSIP'] =
-					$this->talkConfig->isSIPConfigured()
+				$roomData['canEnableSIP']
+					= $this->talkConfig->isSIPConfigured()
 					&& !preg_match(Room::SIP_INCOMPATIBLE_REGEX, $room->getToken())
 					&& ($room->getType() === Room::TYPE_GROUP || $room->getType() === Room::TYPE_PUBLIC)
 					&& $currentParticipant->hasModeratorPermissions(false)
 					&& $this->talkConfig->canUserEnableSIP($currentUser);
+				$roomData['hasScheduledMessages'] = $currentParticipant->getHasScheduledMessages();
 			}
 		} elseif ($attendee->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
 			$lastReadMessage = $attendee->getLastReadMessage();
@@ -352,9 +368,9 @@ class RoomFormatter {
 			$roomData['remoteToken'] = $room->getRemoteToken();
 		}
 
-		if ($room->getLobbyState() === Webinary::LOBBY_NON_MODERATORS &&
-			!$currentParticipant->hasModeratorPermissions() &&
-			!($currentParticipant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+		if ($room->getLobbyState() === Webinary::LOBBY_NON_MODERATORS
+			&& !$currentParticipant->hasModeratorPermissions()
+			&& !($currentParticipant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
 			// No participants and chat messages for users in the lobby.
 			$roomData['hasCall'] = false;
 			$roomData['unreadMessages'] = 0;
@@ -395,12 +411,14 @@ class RoomFormatter {
 
 		$skipLastMessage = $skipLastMessage || $attendee->isSensitive();
 		$lastMessage = $skipLastMessage ? null : $room->getLastMessage();
-		if (!$room->isFederatedConversation() && $lastMessage instanceof IComment) {
+		if ($lastMessage instanceof IComment && !$room->isFederatedConversation()) {
 			$lastMessageData = $this->formatLastMessage(
 				$responseFormat,
 				$room,
 				$currentParticipant,
 				$lastMessage,
+				$thread,
+				$isThreadInfoComplete,
 			);
 			if ($lastMessageData !== null) {
 				$roomData['lastMessage'] = $lastMessageData;
@@ -446,6 +464,8 @@ class RoomFormatter {
 		Room $room,
 		Participant $participant,
 		IComment $lastMessage,
+		?Thread $thread = null,
+		bool $isThreadInfoComplete = false,
 	): ?array {
 		$message = $this->messageParser->createMessage($room, $participant, $lastMessage, $this->l10n);
 		$this->messageParser->parseMessage($message, true);
@@ -455,11 +475,17 @@ class RoomFormatter {
 		}
 
 		$now = $this->timeFactory->getDateTime();
-		$expireDate = $message->getComment()->getExpireDate();
+		$expireDate = $message->getComment()?->getExpireDate();
 		if ($expireDate instanceof \DateTime && $expireDate < $now) {
 			return null;
 		}
 
-		return $message->toArray($responseFormat);
+		if ($thread === null && $isThreadInfoComplete === false) {
+			try {
+				$thread = $this->threadService->findByThreadId($room->getId(), (int)$lastMessage->getTopmostParentId());
+			} catch (DoesNotExistException) {
+			}
+		}
+		return $message->toArray($responseFormat, $thread);
 	}
 }
