@@ -9,6 +9,8 @@ declare(strict_types=1);
 namespace OCA\Talk\Service;
 
 use InvalidArgumentException;
+use OC\User\LazyUser;
+use OCA\Files_Sharing\Event\UserShareAccessUpdatedEvent;
 use OCA\Talk\Config;
 use OCA\Talk\Events\AParticipantModifiedEvent;
 use OCA\Talk\Events\ARoomModifiedEvent;
@@ -46,6 +48,7 @@ use OCA\Talk\Exceptions\RoomProperty\RecordingConsentException;
 use OCA\Talk\Exceptions\RoomProperty\SipConfigurationException;
 use OCA\Talk\Exceptions\RoomProperty\TypeException;
 use OCA\Talk\Manager;
+use OCA\Talk\Model\Attachment;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\BreakoutRoom;
 use OCA\Talk\Participant;
@@ -62,6 +65,7 @@ use OCP\HintException;
 use OCP\IDBConnection;
 use OCP\IL10N;
 use OCP\IUser;
+use OCP\IUserManager;
 use OCP\Log\Audit\CriticalActionPerformedEvent;
 use OCP\Security\Events\ValidatePasswordPolicyEvent;
 use OCP\Security\IHasher;
@@ -88,6 +92,7 @@ class RoomService {
 		protected LoggerInterface $logger,
 		protected IL10N $l10n,
 		protected IManager $calendarManager,
+		protected IUserManager $userManager,
 	) {
 	}
 
@@ -204,8 +209,8 @@ class RoomService {
 			throw new CreationException(CreationException::REASON_OBJECT_TYPE);
 		}
 
-		if (($objectType !== '' && $objectId === '') ||
-			($objectType === '' && $objectId !== '')) {
+		if (($objectType !== '' && $objectId === '')
+			|| ($objectType === '' && $objectId !== '')) {
 			throw new CreationException(CreationException::REASON_OBJECT);
 		}
 
@@ -590,7 +595,7 @@ class RoomService {
 
 	/**
 	 * @param Room $room
-	 * @param integer $status 0 none|1 video|2 audio
+	 * @psalm-param Room::RECORDING_* $status
 	 * @param Participant|null $participant the Participant that changed the
 	 *                                      state, null for the current user
 	 * @throws CallRecordingException
@@ -848,6 +853,56 @@ class RoomService {
 		$this->dispatcher->dispatchTyped($event);
 	}
 
+	/**
+	 * Set the ID of the language to use for live transcriptions in the given
+	 * room.
+	 *
+	 * This method is not meant to be directly used; use
+	 * "LiveTranscriptionService::setLanguage" instead, which only sets the
+	 * language in the room if the external app is available and the language is
+	 * valid.
+	 *
+	 * @param Room $room
+	 * @param string $newState ID of the language to set
+	 */
+	public function setLiveTranscriptionLanguageId(Room $room, string $newState): void {
+		$oldState = $room->getLiveTranscriptionLanguageId();
+		if ($newState === $oldState) {
+			return;
+		}
+
+		$event = new BeforeRoomModifiedEvent($room, ARoomModifiedEvent::PROPERTY_LIVE_TRANSCRIPTION_LANGUAGE_ID, $newState, $oldState);
+		$this->dispatcher->dispatchTyped($event);
+
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('transcription_language', $update->createNamedParameter($newState, IQueryBuilder::PARAM_STR))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+
+		$room->setLiveTranscriptionLanguageId($newState);
+
+		$event = new RoomModifiedEvent($room, ARoomModifiedEvent::PROPERTY_LIVE_TRANSCRIPTION_LANGUAGE_ID, $newState, $oldState);
+		$this->dispatcher->dispatchTyped($event);
+	}
+
+	public function setLastPinnedId(Room $room, int $lastPinnedId): void {
+		$event = new BeforeRoomModifiedEvent($room, ARoomModifiedEvent::PROPERTY_LAST_PINNED_ID, $lastPinnedId);
+		$this->dispatcher->dispatchTyped($event);
+
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('last_pinned_id', $update->createNamedParameter($lastPinnedId))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+
+		$room->setLastPinnedId($lastPinnedId);
+		$this->participantService->resetHiddenPinnedId($room, $lastPinnedId);
+
+		$event = new RoomModifiedEvent($room, ARoomModifiedEvent::PROPERTY_LAST_PINNED_ID, $lastPinnedId);
+		$this->dispatcher->dispatchTyped($event);
+	}
+
 	public function setAssignedSignalingServer(Room $room, ?int $signalingServer): bool {
 		$update = $this->db->getQueryBuilder();
 		$update->update('talk_rooms')
@@ -1203,6 +1258,14 @@ class RoomService {
 		$room->setFederatedParticipants($hasFederation);
 	}
 
+	public function setHasAttachments(Room $room): void {
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('has_attachments', $update->createNamedParameter(Attachment::ATTACHMENTS_ATLEAST_ONE, IQueryBuilder::PARAM_INT))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+	}
+
 	public function setLastActivity(Room $room, \DateTime $now): void {
 		$update = $this->db->getQueryBuilder();
 		$update->update('talk_rooms')
@@ -1310,6 +1373,10 @@ class RoomService {
 				$this->logger->error('An error (' . $e->getReason() . ') occurred while trying to sync mentionPermissions of ' . $local->getId() . ' to ' . $host['mentionPermissions'], ['exception' => $e]);
 			}
 		}
+		if (isset($host['lastPinnedId']) && $host['lastPinnedId'] !== $local->getLastPinnedId()) {
+			$this->setLastPinnedId($local, $host['lastPinnedId']);
+			$changed[] = ARoomModifiedEvent::PROPERTY_LAST_PINNED_ID;
+		}
 		if (isset($host['messageExpiration']) && $host['messageExpiration'] !== $local->getMessageExpiration()) {
 			try {
 				$this->setMessageExpiration($local, $host['messageExpiration']);
@@ -1377,12 +1444,22 @@ class RoomService {
 			$delete->executeStatement();
 		}
 
+		// Get user ids for clearing the share access cache after deleting
+		$userIds = $this->participantService->getParticipantUserIds($room);
+
 		// Delete attendees
 		$delete = $this->db->getQueryBuilder();
 		$delete->delete('talk_attendees')
 			->where($delete->expr()->eq('room_id', $delete->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
 		$delete->executeStatement();
 
+		// Clear share access cache
+		foreach ($userIds as $userId) {
+			$user = new LazyUser($userId, $this->userManager);
+			$event = new UserShareAccessUpdatedEvent($user);
+			$this->dispatcher->dispatchTyped($event);
+		}
+
 		// Delete room
 		$delete = $this->db->getQueryBuilder();
 		$delete->delete('talk_rooms')
