@@ -9,6 +9,8 @@ declare(strict_types=1);
 namespace OCA\Talk\Share;
 
 use OC\Files\Cache\Cache;
+use OC\User\LazyUser;
+use OCA\Talk\Config;
 use OCA\Talk\Events\BeforeDuplicateShareSentEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
@@ -27,12 +29,16 @@ use OCP\Files\IMimeTypeLoader;
 use OCP\Files\Node;
 use OCP\IDBConnection;
 use OCP\IL10N;
+use OCP\IUser;
+use OCP\IUserManager;
 use OCP\Security\ISecureRandom;
 use OCP\Share\Exceptions\GenericShareException;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IManager as IShareManager;
+use OCP\Share\IPartialShareProvider;
 use OCP\Share\IShare;
 use OCP\Share\IShareProvider;
+use OCP\Share\IShareProviderGetUsers;
 
 /**
  * Share provider for room shares.
@@ -44,7 +50,7 @@ use OCP\Share\IShareProvider;
  * Like in group shares, a recipient can move or delete a share without
  * modifying the share for the other users in the room.
  */
-class RoomShareProvider implements IShareProvider {
+class RoomShareProvider implements IShareProvider, IPartialShareProvider, IShareProviderGetUsers {
 	use TTransactional;
 	// Special share type for user modified room shares
 	public const SHARE_TYPE_USERROOM = 11;
@@ -65,6 +71,8 @@ class RoomShareProvider implements IShareProvider {
 		protected ITimeFactory $timeFactory,
 		private IL10N $l,
 		private IMimeTypeLoader $mimeTypeLoader,
+		private IUserManager $userManager,
+		protected Config $config,
 	) {
 		$this->sharesByIdCache = new CappedMemoryCache();
 	}
@@ -436,7 +444,7 @@ class RoomShareProvider implements IShareProvider {
 
 		$update->executeStatement();
 
-		return $this->getShareById((int)$share->getId(), $recipient);
+		return $this->getShareById($share->getId(), $recipient);
 	}
 
 	/**
@@ -507,8 +515,8 @@ class RoomShareProvider implements IShareProvider {
 	 * @param Folder $node
 	 * @param bool $reshares Also get the shares where $user is the owner instead of just the shares where $user is the initiator
 	 * @param bool $shallow Whether the method should stop at the first level, or look into sub-folders.
-	 * @return IShare[][]
-	 * @psalm-return array<array-key, non-empty-list<IShare>>
+	 * @return array<int, list<IShare>>
+	 * @psalm-return array<int, non-empty-list<IShare>>
 	 */
 	#[\Override]
 	public function getSharesInFolder($userId, Folder $node, $reshares, $shallow = true): array {
@@ -618,13 +626,14 @@ class RoomShareProvider implements IShareProvider {
 	/**
 	 * Get share by id
 	 *
-	 * @param int $id
+	 * @param string $id
 	 * @param string|null $recipientId
 	 * @return IShare
 	 * @throws ShareNotFound
 	 */
 	#[\Override]
 	public function getShareById($id, $recipientId = null): IShare {
+		$id = (int)$id;
 		if (($recipientId === null) && isset($this->sharesByIdCache[$id])) {
 			$share = $this->sharesByIdCache[$id];
 		} else {
@@ -726,7 +735,7 @@ class RoomShareProvider implements IShareProvider {
 		if ($allRoomShares) {
 			$stmt = $query->executeQuery();
 
-			while ($data = $stmt->fetch()) {
+			while ($data = $stmt->fetchAssociative()) {
 				if (isset($shareMap[$data['parent']])) {
 					$shareMap[$data['parent']]->setPermissions((int)$data['permissions']);
 					$shareMap[$data['parent']]->setTarget($data['file_target']);
@@ -742,7 +751,7 @@ class RoomShareProvider implements IShareProvider {
 				$query->setParameter('share_ids', $ids, IQueryBuilder::PARAM_INT_ARRAY);
 				$stmt = $query->executeQuery();
 
-				while ($data = $stmt->fetch()) {
+				while ($data = $stmt->fetchAssociative()) {
 					$shareMap[$data['parent']]->setPermissions((int)$data['permissions']);
 					$shareMap[$data['parent']]->setTarget($data['file_target']);
 				}
@@ -855,6 +864,140 @@ class RoomShareProvider implements IShareProvider {
 		return $shares;
 	}
 
+	#[\Override]
+	public function getSharedWithByPath(
+		string $userId,
+		int $shareType,
+		string $path,
+		bool $forChildren,
+		int $limit,
+		int $offset,
+	): iterable {
+		if (str_starts_with($path, '/' . $userId . '/files')) {
+			$path = substr($path, strlen('/' . $userId . '/files'));
+		}
+		$path = rtrim($path, '/');
+
+		if (!$forChildren) {
+			$qb = $this->dbConnection->getQueryBuilder();
+			$qb->select('parent')
+				->from('share')
+				->where($qb->expr()->eq('file_target', $qb->createNamedParameter($path)))
+				->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(self::SHARE_TYPE_USERROOM)))
+				->andWhere($qb->expr()->eq('share_with', $qb->createNamedParameter($userId)));
+
+			$result = $qb->executeQuery();
+			$shareId = $result->fetchColumn();
+			$result->closeCursor();
+
+			if ($shareId !== false) {
+				return $this->getSharesByIds([$shareId], $userId);
+			}
+
+			$attachmentFolder = $this->config->getAttachmentFolder($userId);
+			$escapedAttachmentFolder = preg_quote($attachmentFolder, '/');
+			$pathWithPlaceholder = preg_replace("/^$escapedAttachmentFolder/", self::TALK_FOLDER_PLACEHOLDER, $path);
+
+			$qb = $this->dbConnection->getQueryBuilder();
+			$qb->select('id', 'share_with')
+				->from('share')
+				->where($qb->expr()->eq('file_target', $qb->createNamedParameter($pathWithPlaceholder)))
+				->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)));
+
+			$result = $qb->executeQuery();
+			$potentialShare = $result->fetch();
+			$result->closeCursor();
+
+			if ($potentialShare !== false && $this->manager->isUserAttendeeInRoom($userId, $potentialShare['share_with'])) {
+				return $this->getSharesByIds([$potentialShare['id']], $userId);
+			}
+
+			return [];
+		}
+
+		$allRooms = $this->manager->getRoomTokensWithAttachmentsForUser($userId);
+
+		if (empty($allRooms)) {
+			return [];
+		}
+
+		/** @var IShare[] $shares */
+		$shares = [];
+
+		$attachmentFolder = $this->config->getAttachmentFolder($userId);
+		$escapedAttachmentFolder = preg_quote($attachmentFolder, '/');
+		$pathWithPlaceholder = preg_replace("/^$escapedAttachmentFolder/", self::TALK_FOLDER_PLACEHOLDER, $path);
+		$childPathTemplate = $this->dbConnection->escapeLikeParameter($path) . '/_%';
+		$childPathTemplatePlaceholder = $this->dbConnection->escapeLikeParameter($pathWithPlaceholder) . '/_%';
+
+		$chunks = array_chunk($allRooms, 100);
+		foreach ($chunks as $rooms) {
+			$qb = $this->dbConnection->getQueryBuilder();
+			$qb->select('s.*',
+				'f.fileid', 'f.path', 'f.permissions AS f_permissions', 'f.storage', 'f.path_hash',
+				'f.parent AS f_parent', 'f.name', 'f.mimetype', 'f.mimepart', 'f.size', 'f.mtime', 'f.storage_mtime',
+				'f.encrypted', 'f.unencrypted_size', 'f.etag', 'f.checksum'
+			)
+				->selectAlias('st.id', 'storage_string_id')
+				->from('share', 's')
+				->orderBy('s.id', 'ASC')
+				->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
+				->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'));
+
+			if ($limit !== -1) {
+				$qb->setMaxResults($limit);
+			}
+
+			$onClause = $qb->expr()->andX(
+				$qb->expr()->eq('sc.parent', 's.id'),
+				$qb->expr()->eq('sc.share_type', $qb->createNamedParameter(self::SHARE_TYPE_USERROOM)),
+				$qb->expr()->eq('sc.share_with', $qb->createNamedParameter($userId)),
+			);
+			$qb->leftJoin('s', 'share', 'sc', $onClause);
+			$qb->selectAlias('sc.file_target', 'sc_file_target')
+				->selectAlias('sc.permissions', 'sc_permissions');
+
+			$qb->andWhere(
+				$qb->expr()->like('s.file_target', $qb->createNamedParameter($childPathTemplatePlaceholder, IQueryBuilder::PARAM_STR)),
+				$qb->expr()->orX(
+					$qb->expr()->like('sc.file_target', $qb->createNamedParameter($childPathTemplate, IQueryBuilder::PARAM_STR)),
+					$qb->expr()->isNull('sc.file_target'),
+				),
+			);
+
+			$qb->andWhere($qb->expr()->eq('s.share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
+				->andWhere($qb->expr()->in('s.share_with', $qb->createNamedParameter(
+					$rooms,
+					IQueryBuilder::PARAM_STR_ARRAY
+				)));
+
+			$cursor = $qb->executeQuery();
+			while ($data = $cursor->fetch()) {
+				if ($data['uid_initiator'] === $userId || $data['uid_owner'] === $userId) {
+					continue;
+				}
+
+				if (!$this->isAccessibleResult($data)) {
+					continue;
+				}
+
+				if ($offset > 0) {
+					$offset--;
+					continue;
+				}
+
+				$data['file_target'] = $data['sc_file_target'] ?? str_replace(self::TALK_FOLDER_PLACEHOLDER, $attachmentFolder, $data['file_target']);
+				$data['permissions'] = $data['sc_permissions'] ?? $data['permissions'];
+
+				$share = $this->createShareObject($data);
+				$shares[$share->getId()] = $share;
+			}
+			$cursor->closeCursor();
+		}
+
+		return $shares;
+	}
+
 	private function isAccessibleResult(array $data): bool {
 		// exclude shares leading to deleted file entries
 		if ($data['fileid'] === null || $data['path'] === null) {
@@ -865,7 +1008,7 @@ class RoomShareProvider implements IShareProvider {
 		$pathSections = explode('/', $data['path'], 2);
 		// FIXME: would not detect rare md5'd home storage case properly
 		if ($pathSections[0] !== 'files'
-			&& (strpos($data['storage_string_id'], 'home::') === 0 || strpos($data['storage_string_id'], 'object::user') === 0)) {
+			&& (str_starts_with($data['storage_string_id'], 'home::') || str_starts_with($data['storage_string_id'], 'object::user'))) {
 			return false;
 		}
 		return true;
@@ -1167,7 +1310,7 @@ class RoomShareProvider implements IShareProvider {
 	 * Get all the shares in this provider returned as iterable to reduce memory
 	 * overhead
 	 *
-	 * @return iterable
+	 * @return iterable<IShare>
 	 * @since 18.0.0
 	 */
 	#[\Override]
@@ -1190,4 +1333,31 @@ class RoomShareProvider implements IShareProvider {
 		}
 		$cursor->closeCursor();
 	}
+
+	#[\Override]
+	public function getUsersForShare(IShare $share): iterable {
+		if ($share->getShareType() === self::SHARE_TYPE_USERROOM) {
+			// User record for a share, user is the shared_with
+			return [new LazyUser($share->getSharedWith(), $this->userManager)];
+		}
+
+		if ($share->getShareType() !== IShare::TYPE_ROOM) {
+			return [];
+		}
+
+		// Room share entry, shared_with is the conversation token
+		try {
+			$room = $this->manager->getRoomByToken($share->getSharedWith());
+		} catch (RoomNotFoundException) {
+			return [];
+		}
+
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+			return array_map(fn (string $userId): IUser => new LazyUser($userId, $this->userManager), json_decode($room->getName(), true));
+		}
+
+		// Get all user ids for the room
+		$userIds = $this->participantService->getParticipantUserIds($room);
+		return array_map(fn (string $userId): IUser => new LazyUser($userId, $this->userManager), $userIds);
+	}
 }
