@@ -2,30 +2,20 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Signaling;
 
+use OCA\Talk\AppInfo\Application;
+use OCA\Talk\Chat\ChatManager;
+use OCA\Talk\Chat\MessageParser;
 use OCA\Talk\Config;
 use OCA\Talk\Events\AMessageSentEvent;
 use OCA\Talk\Events\AParticipantModifiedEvent;
+use OCA\Talk\Events\AReactionEvent;
+use OCA\Talk\Events\ARoomEvent;
 use OCA\Talk\Events\ARoomModifiedEvent;
 use OCA\Talk\Events\ASystemMessageSentEvent;
 use OCA\Talk\Events\AttendeeRemovedEvent;
@@ -33,6 +23,7 @@ use OCA\Talk\Events\AttendeesAddedEvent;
 use OCA\Talk\Events\AttendeesRemovedEvent;
 use OCA\Talk\Events\BeforeAttendeeRemovedEvent;
 use OCA\Talk\Events\BeforeRoomDeletedEvent;
+use OCA\Talk\Events\BeforeRoomSyncedEvent;
 use OCA\Talk\Events\BeforeSessionLeftRoomEvent;
 use OCA\Talk\Events\CallEndedForEveryoneEvent;
 use OCA\Talk\Events\ChatMessageSentEvent;
@@ -40,25 +31,78 @@ use OCA\Talk\Events\GuestJoinedRoomEvent;
 use OCA\Talk\Events\GuestsCleanedUpEvent;
 use OCA\Talk\Events\LobbyModifiedEvent;
 use OCA\Talk\Events\ParticipantModifiedEvent;
+use OCA\Talk\Events\ReactionAddedEvent;
+use OCA\Talk\Events\ReactionRemovedEvent;
+use OCA\Talk\Events\RoomExtendedEvent;
 use OCA\Talk\Events\RoomModifiedEvent;
+use OCA\Talk\Events\RoomSyncedEvent;
 use OCA\Talk\Events\SessionLeftRoomEvent;
 use OCA\Talk\Events\SystemMessageSentEvent;
 use OCA\Talk\Events\SystemMessagesMultipleSentEvent;
 use OCA\Talk\Events\UserJoinedRoomEvent;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\BreakoutRoom;
+use OCA\Talk\Model\Message;
+use OCA\Talk\Model\Poll;
+use OCA\Talk\Model\Session;
+use OCA\Talk\Model\Vote;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
+use OCA\Talk\Service\PollService;
 use OCA\Talk\Service\SessionService;
+use OCA\Talk\Service\ThreadService;
+use OCP\AppFramework\Db\DoesNotExistException;
+use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
+use OCP\L10N\IFactory;
 use OCP\Server;
 
 /**
  * @template-implements IEventListener<Event>
  */
 class Listener implements IEventListener {
+	public const EXTERNAL_SIGNALING_PROPERTIES = [
+		ARoomModifiedEvent::PROPERTY_BREAKOUT_ROOM_MODE,
+		ARoomModifiedEvent::PROPERTY_BREAKOUT_ROOM_STATUS,
+		ARoomModifiedEvent::PROPERTY_CALL_RECORDING,
+		ARoomModifiedEvent::PROPERTY_DEFAULT_PERMISSIONS,
+		ARoomModifiedEvent::PROPERTY_DESCRIPTION,
+		ARoomModifiedEvent::PROPERTY_LISTABLE,
+		ARoomModifiedEvent::PROPERTY_LOBBY,
+		ARoomModifiedEvent::PROPERTY_NAME,
+		ARoomModifiedEvent::PROPERTY_PASSWORD,
+		ARoomModifiedEvent::PROPERTY_READ_ONLY,
+		ARoomModifiedEvent::PROPERTY_SIP_ENABLED,
+		ARoomModifiedEvent::PROPERTY_TYPE,
+	];
+
+	public const SYSTEM_MESSAGE_TYPE_RELAY = [
+		'call_started',
+		'call_joined',
+		'call_left',
+		'call_ended',
+		'call_ended_everyone',
+		'thread_created',
+		'thread_renamed',
+		'message_deleted',
+		'message_edited',
+		'moderator_promoted',
+		'moderator_demoted',
+		'guest_moderator_promoted',
+		'guest_moderator_demoted',
+		'file_shared',
+		'object_shared',
+		'history_cleared',
+		'poll_voted',
+		'poll_closed',
+		'recording_started',
+		'recording_stopped',
+	];
+
+	protected bool $pauseRoomModifiedListener = false;
+
 	public function __construct(
 		protected Config $talkConfig,
 		protected Messages $internalSignaling,
@@ -66,9 +110,15 @@ class Listener implements IEventListener {
 		protected Manager $manager,
 		protected ParticipantService $participantService,
 		protected SessionService $sessionService,
+		protected ITimeFactory $timeFactory,
+		protected MessageParser $messageParser,
+		protected ThreadService $threadService,
+		protected IFactory $l10nFactory,
+		protected PollService $pollService,
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if ($this->talkConfig->getSignalingMode() === Config::SIGNALING_INTERNAL) {
 			$this->handleInternalSignaling($event);
@@ -108,7 +158,6 @@ class Listener implements IEventListener {
 
 	protected function refreshParticipantListRoomModified(RoomModifiedEvent $event): void {
 		if (!in_array($event->getProperty(), [
-			ARoomModifiedEvent::PROPERTY_CALL_PERMISSIONS,
 			ARoomModifiedEvent::PROPERTY_DEFAULT_PERMISSIONS,
 		], true)) {
 			return;
@@ -121,6 +170,9 @@ class Listener implements IEventListener {
 		match (get_class($event)) {
 			RoomModifiedEvent::class,
 			LobbyModifiedEvent::class => $this->notifyRoomModified($event),
+			RoomExtendedEvent::class => $this->notifyRoomExtended($event),
+			BeforeRoomSyncedEvent::class => $this->pauseRoomModifiedListener(),
+			RoomSyncedEvent::class => $this->notifyRoomSynced($event),
 			BeforeRoomDeletedEvent::class => $this->notifyBeforeRoomDeleted($event),
 			CallEndedForEveryoneEvent::class => $this->notifyCallEndedForEveryone($event),
 			GuestsCleanedUpEvent::class => $this->notifyGuestsCleanedUp($event),
@@ -129,34 +181,25 @@ class Listener implements IEventListener {
 			AttendeesRemovedEvent::class => $this->notifyAttendeesRemoved($event),
 			ParticipantModifiedEvent::class => $this->notifyParticipantModified($event),
 			SessionLeftRoomEvent::class => $this->notifySessionLeftRoom($event),
-			ChatMessageSentEvent::class,
+			ChatMessageSentEvent::class => $this->notifyMessageSent($event),
 			SystemMessageSentEvent::class,
-			SystemMessagesMultipleSentEvent::class => $this->notifyMessageSent($event),
+			SystemMessagesMultipleSentEvent::class => $this->notifySystemMessageSent($event),
+			ReactionAddedEvent::class,
+			ReactionRemovedEvent::class => $this->notifyReactionSent($event),
 			default => null, // Ignoring events subscribed by the internal signaling
 		};
 	}
 
+	protected function pauseRoomModifiedListener(): void {
+		$this->pauseRoomModifiedListener = true;
+	}
+
 	protected function notifyRoomModified(ARoomModifiedEvent $event): void {
-		if (!in_array($event->getProperty(), [
-			ARoomModifiedEvent::PROPERTY_BREAKOUT_ROOM_MODE,
-			ARoomModifiedEvent::PROPERTY_BREAKOUT_ROOM_STATUS,
-			ARoomModifiedEvent::PROPERTY_CALL_RECORDING,
-			ARoomModifiedEvent::PROPERTY_CALL_PERMISSIONS,
-			ARoomModifiedEvent::PROPERTY_DEFAULT_PERMISSIONS,
-			ARoomModifiedEvent::PROPERTY_DESCRIPTION,
-			ARoomModifiedEvent::PROPERTY_LISTABLE,
-			ARoomModifiedEvent::PROPERTY_LOBBY,
-			ARoomModifiedEvent::PROPERTY_NAME,
-			ARoomModifiedEvent::PROPERTY_PASSWORD,
-			ARoomModifiedEvent::PROPERTY_READ_ONLY,
-			ARoomModifiedEvent::PROPERTY_SIP_ENABLED,
-			ARoomModifiedEvent::PROPERTY_TYPE,
-		], true)) {
+		if (!in_array($event->getProperty(), self::EXTERNAL_SIGNALING_PROPERTIES, true)) {
 			return;
 		}
 
-		if ($event->getProperty() === ARoomModifiedEvent::PROPERTY_CALL_PERMISSIONS
-			|| $event->getProperty() === ARoomModifiedEvent::PROPERTY_DEFAULT_PERMISSIONS) {
+		if ($event->getProperty() === ARoomModifiedEvent::PROPERTY_DEFAULT_PERMISSIONS) {
 			$this->notifyRoomPermissionsModified($event);
 			// The room permission itself does not need a signaling message anymore
 			return;
@@ -171,12 +214,33 @@ class Listener implements IEventListener {
 		$this->externalSignaling->roomModified($event->getRoom());
 	}
 
-	protected function notifyRoomRecordingModified(ARoomModifiedEvent $event): void {
+	protected function notifyRoomSynced(RoomSyncedEvent $event): void {
+		$this->pauseRoomModifiedListener = false;
+		if (empty(array_intersect($event->getProperties(), self::EXTERNAL_SIGNALING_PROPERTIES))) {
+			return;
+		}
+
+		if (in_array(ARoomModifiedEvent::PROPERTY_DEFAULT_PERMISSIONS, $event->getProperties(), true)) {
+			$this->notifyRoomPermissionsModified($event);
+		}
+
+		if (in_array(ARoomModifiedEvent::PROPERTY_CALL_RECORDING, $event->getProperties(), true)) {
+			$this->notifyRoomRecordingModified($event);
+		}
+
+		if (in_array(ARoomModifiedEvent::PROPERTY_BREAKOUT_ROOM_STATUS, $event->getProperties(), true)) {
+			$this->notifyBreakoutRoomStatusModified($event);
+		}
+
+		$this->externalSignaling->roomModified($event->getRoom());
+	}
+
+	protected function notifyRoomRecordingModified(ARoomEvent $event): void {
 		$room = $event->getRoom();
 		$message = [
 			'type' => 'recording',
 			'recording' => [
-				'status' => $event->getNewValue(),
+				'status' => $room->getCallRecording(),
 			],
 		];
 
@@ -192,7 +256,7 @@ class Listener implements IEventListener {
 
 		$this->externalSignaling->roomInCallChanged(
 			$event->getRoom(),
-			$event->getNewValue(),
+			$event->getCallFlag(),
 			[],
 			true
 		);
@@ -258,7 +322,7 @@ class Listener implements IEventListener {
 		$this->externalSignaling->participantsModified($event->getRoom(), $sessionIds);
 	}
 
-	protected function notifyRoomPermissionsModified(ARoomModifiedEvent $event): void {
+	protected function notifyRoomPermissionsModified(ARoomEvent $event): void {
 		$sessionIds = [];
 
 		// Setting the room permissions resets the permissions of all
@@ -342,7 +406,7 @@ class Listener implements IEventListener {
 		}
 	}
 
-	protected function notifyBreakoutRoomStatusModified(ARoomModifiedEvent $event): void {
+	protected function notifyBreakoutRoomStatusModified(ARoomEvent $event): void {
 		$room = $event->getRoom();
 		if ($room->getBreakoutRoomStatus() === BreakoutRoom::STATUS_STARTED) {
 			$this->notifyBreakoutRoomStarted($room);
@@ -372,6 +436,27 @@ class Listener implements IEventListener {
 		}
 	}
 
+	protected function notifyRoomExtended(RoomExtendedEvent $event): void {
+		$room = $event->getRoom();
+
+		if ($room->getCallFlag() === Participant::FLAG_DISCONNECTED) {
+			return;
+		}
+
+		$timeout = $this->timeFactory->getTime() - Session::SESSION_TIMEOUT;
+		$participants = $this->participantService->getParticipantsInCall($room, $timeout);
+
+		$sessionIds = [];
+		foreach ($participants as $participant) {
+			if ($participant->getSession() instanceof Session) {
+				$sessionIds[] = $participant->getSession()->getSessionId();
+			}
+		}
+
+		$newRoom = $event->getNewRoom();
+		$this->externalSignaling->switchToRoom($room, $newRoom->getToken(), $sessionIds);
+	}
+
 	/**
 	 * @param Participant $targetParticipant
 	 * @param Participant[] $participants
@@ -415,17 +500,201 @@ class Listener implements IEventListener {
 	}
 
 	protected function notifyMessageSent(AMessageSentEvent $event): void {
-		if ($event instanceof ASystemMessageSentEvent && $event->shouldSkipLastActivityUpdate()) {
+		if ($event instanceof ASystemMessageSentEvent) {
+			$this->notifySystemMessageSent($event);
 			return;
 		}
 
+		$comment = $event->getComment();
 		$room = $event->getRoom();
-		$message = [
+		$data = [
 			'type' => 'chat',
 			'chat' => [
 				'refresh' => true,
 			],
 		];
-		$this->externalSignaling->sendRoomMessage($room, $message);
+
+		$l10n = $this->l10nFactory->get(Application::APP_ID, 'en');
+		$message = $this->messageParser->createMessage($event->getRoom(), null, $comment, $l10n);
+		$this->messageParser->parseMessage($message);
+
+		if ($message->getVisibility() === false) {
+			$this->externalSignaling->sendRoomMessage($room, $data);
+			return;
+		}
+
+		$threadId = (int)$comment->getTopmostParentId() ?: $comment->getId();
+		try {
+			$thread = $this->threadService->findByThreadId($room->getId(), (int)$threadId);
+		} catch (DoesNotExistException) {
+			$thread = null;
+		}
+		$data['chat']['comment'] = $message->toArray('json', $thread);
+
+		$parent = $event->getParent();
+		if ($parent !== null) {
+			$parentMessage = $this->messageParser->createMessage($event->getRoom(), null, $parent, $l10n);
+			$this->messageParser->parseMessage($parentMessage);
+			$data['chat']['comment']['parent'] = $parentMessage->toArray('json', $thread);
+		}
+
+		$this->externalSignaling->sendRoomMessage($room, $data);
+	}
+
+	protected function notifySystemMessageSent(ASystemMessageSentEvent $event): void {
+		$comment = $event->getComment();
+		$messageDecoded = json_decode($comment->getMessage(), true);
+		$params = $messageDecoded['parameters'] ?? [];
+		$messageType = $messageDecoded['message'] ?? '';
+
+		if ($event->shouldSkipLastActivityUpdate() === true
+			&& !in_array($messageType, ['message_deleted', 'message_edited', 'thread_created', 'thread_renamed'], true)
+		) {
+			return;
+		}
+
+		$room = $event->getRoom();
+		$data = [
+			'type' => 'chat',
+			'chat' => [
+				'refresh' => true,
+			],
+		];
+
+		if (!in_array($messageType, self::SYSTEM_MESSAGE_TYPE_RELAY, true)) {
+			$this->externalSignaling->sendRoomMessage($room, $data);
+			return;
+		}
+
+		$thread = null;
+		if ($messageType === 'thread_created' || $messageType === 'thread_renamed') {
+			$threadId = (int)$comment->getTopmostParentId() ?: $comment->getId();
+			try {
+				$thread = $this->threadService->findByThreadId($room->getId(), (int)$threadId);
+			} catch (DoesNotExistException) {
+			}
+		}
+
+		$l10n = $this->l10nFactory->get(Application::APP_ID, 'en');
+		$message = $this->messageParser->createMessage($event->getRoom(), null, $comment, $l10n);
+		$this->messageParser->parseMessage($message);
+		if ($message->getVisibility() === false) {
+			$this->externalSignaling->sendRoomMessage($room, $data);
+			return;
+		}
+
+		$data['chat']['comment'] = $message->toArray('json', $thread);
+
+		if ($messageType === 'call_started') {
+			$metaData = $comment->getMetaData() ?? [];
+			$silentCall = $metaData[Message::METADATA_SILENT] ?? false;
+			$data['chat']['comment']['call']['silent'] = $silentCall;
+		}
+
+		if ($messageType === 'object_shared' && isset($params['objectType']) && $params['objectType'] === 'talk-poll') {
+			$poll = $this->pollService->getPoll($event->getRoom()->getId(), $params['objectId']);
+			$data['chat']['comment']['poll'] = $poll->renderAsPoll();
+		}
+
+		if ($messageType === 'poll_voted' && isset($params['poll']['id'])) {
+			$poll = $this->pollService->getPoll($event->getRoom()->getId(), $params['poll']['id']);
+			$data['chat']['comment']['poll'] = $poll->renderAsPoll();
+		}
+
+		if ($messageType === 'poll_closed' && isset($params['poll']['id'])) {
+			$poll = $this->pollService->getPoll($event->getRoom()->getId(), $params['poll']['id']);
+			$data['chat']['comment']['poll'] = $poll->renderAsPoll();
+			if ($poll->getResultMode() !== Poll::MODE_HIDDEN) {
+				$votes = $this->pollService->getVotes($poll);
+				$data['chat']['comment']['poll']['votes'] = array_map(fn (Vote $vote) => $vote->asArray(), $votes);
+			}
+		}
+
+		if ($messageType === 'thread_created' || $messageType === 'thread_renamed') {
+			$data['chat']['comment']['threadInfo']['thread'] = [
+				'id' => $thread->getId(),
+				'roomToken' => $room->getToken(),
+				'title' => $thread->getName(),
+				'lastMessageId' => $thread->getLastMessageId(),
+				'lastActivity' => $thread->getLastActivity()?->getTimestamp() ?? 0,
+				'numReplies' => $thread->getNumReplies(),
+			];
+			$data['chat']['comment']['threadInfo']['attendee'] = ['notificationLevel' => 0];
+			$data['chat']['comment']['threadInfo']['first'] = $thread->toArray($room);
+			$data['chat']['comment']['threadInfo']['last'] = null;
+			$this->externalSignaling->sendRoomMessage($room, $data);
+			return;
+		}
+
+		$parent = $event->getParent();
+		if ($parent !== null) {
+			$parentMessage = $this->messageParser->createMessage($event->getRoom(), null, $parent, $l10n);
+			$this->messageParser->parseMessage($parentMessage);
+			$data['chat']['comment']['parent'] = $parentMessage->toArray('json', $thread);
+		}
+
+		$this->externalSignaling->sendRoomMessage($room, $data);
+	}
+
+	protected function notifyReactionSent(AReactionEvent $event): void {
+		$room = $event->getRoom();
+		$data = [
+			'type' => 'chat',
+			'chat' => [
+				'refresh' => true,
+			],
+		];
+
+		$comment = $event->getMessage();
+		$messageType = $event instanceof ReactionAddedEvent ? ChatManager::VERB_REACTION : 'reaction_revoked';
+
+		$threadId = (int)$comment->getTopmostParentId() ?: $comment->getId();
+		try {
+			$thread = $this->threadService->findByThreadId($room->getId(), (int)$threadId);
+		} catch (DoesNotExistException) {
+			$thread = null;
+		}
+
+		$reactions = $comment->getReactions();
+		if ($event instanceof ReactionRemovedEvent) {
+			if (array_key_exists($event->getReaction(), $reactions) && $reactions[$event->getReaction()] > 1) {
+				--$reactions[$event->getReaction()];
+			} else {
+				unset($reactions[$event->getReaction()]);
+			}
+		} elseif ($event instanceof ReactionAddedEvent) {
+			if (array_key_exists($event->getReaction(), $reactions)) {
+				++$reactions[$event->getReaction()];
+			} else {
+				$reactions[$event->getReaction()] = 1;
+			}
+		}
+
+		$comment->setReactions($reactions);
+		$l10n = $this->l10nFactory->get(Application::APP_ID, 'en');
+		$message = $this->messageParser->createMessage($event->getRoom(), null, $comment, $l10n);
+		$this->messageParser->parseMessage($message);
+		// Build reaction message data
+		$data['chat']['comment'] = [
+			'id' => $event->getReactionMessage()?->getId(),
+			'token' => $event->getRoom()->getToken(),
+			'actorType' => $event->getActorType(),
+			'actorId' => $event->getActorId(),
+			'actorDisplayName' => $event->getActorDisplayName(),
+			'timestamp' => $this->timeFactory->getTime(),
+			'message' => $event->getReaction(),
+			'messageParameters' => [],
+			'systemMessage' => $messageType,
+			'messageType' => ChatManager::VERB_SYSTEM,
+			'isReplyable' => false,
+			'referenceId' => '',
+			'reactions' => [],
+			'markdown' => false ,
+			'expirationTimestamp' => $message->getExpirationDateTime()?->getTimestamp() ?? 0,
+			'threadId' => $threadId,
+		];
+
+		$data['chat']['comment']['parent'] = $message->toArray('json', $thread);
+		$this->externalSignaling->sendRoomMessage($room, $data);
 	}
 }
