@@ -11,6 +11,7 @@ use Traversable;
 
 use function array_keys;
 use function count;
+use function iterator_to_array;
 
 /**
  * @internal
@@ -38,6 +39,14 @@ final class FunctionsContainer implements IteratorAggregate, Countable
         return $this->function($key);
     }
 
+    /**
+     * @return array<FunctionObject>
+     */
+    public function toArray(): array
+    {
+        return iterator_to_array($this);
+    }
+
     public function getIterator(): Traversable
     {
         foreach (array_keys($this->callables) as $key) {
