@@ -5,10 +5,13 @@ declare(strict_types=1);
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Definition;
 
 use Countable;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\Types\Generics;
 use IteratorAggregate;
 use Traversable;
 
+use function array_map;
 use function array_values;
+use function count;
 
 /**
  * @internal
@@ -17,7 +20,7 @@ use function array_values;
  */
 final class Parameters implements IteratorAggregate, Countable
 {
-    /** @var ParameterDefinition[] */
+    /** @var array<non-empty-string, ParameterDefinition> */
     private array $parameters = [];
 
     public function __construct(ParameterDefinition ...$parameters)
@@ -45,12 +48,22 @@ final class Parameters implements IteratorAggregate, Countable
         return array_values($this->parameters)[$index];
     }
 
-    /**
-     * @return list<ParameterDefinition>
-     */
-    public function toList(): array
+    public function assignGenerics(Generics $generics): self
     {
-        return array_values($this->parameters);
+        return new self(
+            ...array_map(
+                static fn (ParameterDefinition $parameter) => $parameter->assignGenerics($generics),
+                $this->parameters,
+            ),
+        );
+    }
+
+    /**
+     * @return array<non-empty-string, ParameterDefinition>
+     */
+    public function toArray(): array
+    {
+        return $this->parameters;
     }
 
     public function count(): int
@@ -58,6 +71,14 @@ final class Parameters implements IteratorAggregate, Countable
         return count($this->parameters);
     }
 
+    public function forCallable(callable $callable): self
+    {
+        return new self(...array_map(
+            fn (ParameterDefinition $parameter) => $parameter->forCallable($callable),
+            $this->parameters
+        ));
+    }
+
     /**
      * @return Traversable<string, ParameterDefinition>
      */
