@@ -6,10 +6,9 @@ namespace OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\Cache\Compiler;
 
 use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Attributes;
 
+use function array_map;
 use function count;
 use function implode;
-use function is_array;
-use function is_object;
 use function var_export;
 
 /** @internal */
@@ -36,12 +35,16 @@ final class AttributesCompiler
 
         foreach ($attributes as $attribute) {
             $class = $this->classDefinitionCompiler->compile($attribute->class);
-            $arguments = $this->compileAttributeArguments($attribute->arguments);
+            $argumentsCode = $this->compileAttributeArguments($attribute->arguments);
+            $reflectionParts = var_export($attribute->reflectionParts, true);
+            $attributeIndex = var_export($attribute->attributeIndex, true);
 
             $attributesListCode[] = <<<PHP
             new \OCA\Talk\Vendor\CuyZ\Valinor\Definition\AttributeDefinition(
                 $class,
-                [$arguments],
+                $argumentsCode,
+                $reflectionParts,
+                $attributeIndex,
             )
             PHP;
         }
@@ -50,26 +53,16 @@ final class AttributesCompiler
     }
 
     /**
-     * @param array<mixed> $arguments
+     * @param null|list<array<scalar>|scalar> $arguments
      */
-    private function compileAttributeArguments(array $arguments): string
+    private function compileAttributeArguments(?array $arguments): string
     {
-        if (count($arguments) === 0) {
-            return '';
+        if ($arguments === null) {
+            return 'null';
         }
 
-        $argumentsCode = [];
+        $code = array_map(static fn ($value) => var_export($value, true), $arguments);
 
-        foreach ($arguments as $argument) {
-            if (is_object($argument)) {
-                $argumentsCode[] = 'unserialize(' . var_export(serialize($argument), true) . ')';
-            } elseif (is_array($argument)) {
-                $argumentsCode[] = '[' . $this->compileAttributeArguments($argument) . ']';
-            } else {
-                $argumentsCode[] = var_export($argument, true);
-            }
-        }
-
-        return implode(', ', $argumentsCode);
+        return '[' . implode(', ', $code) . ']';
     }
 }
