@@ -5,12 +5,14 @@ declare(strict_types=1);
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Exception;
 
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\ErrorMessage;
+use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\HasCode;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\HasParameters;
-use OCA\Talk\Vendor\CuyZ\Valinor\Utility\String\StringFormatter;
 use RuntimeException;
 
+use function implode;
+
 /** @internal */
-final class CannotParseToDateTime extends RuntimeException implements ErrorMessage, HasParameters
+final class CannotParseToDateTime extends RuntimeException implements ErrorMessage, HasCode, HasParameters
 {
     private string $body = 'Value {source_value} does not match any of the following formats: {formats}.';
 
@@ -26,7 +28,8 @@ final class CannotParseToDateTime extends RuntimeException implements ErrorMessa
             'formats' => '`' . implode('`, `', $formats) . '`',
         ];
 
-        parent::__construct(StringFormatter::for($this), 1630686564);
+        // @infection-ignore-all
+        parent::__construct($this->body);
     }
 
     public function body(): string
@@ -34,6 +37,11 @@ final class CannotParseToDateTime extends RuntimeException implements ErrorMessa
         return $this->body;
     }
 
+    public function code(): string
+    {
+        return 'cannot_parse_datetime_format';
+    }
+
     public function parameters(): array
     {
         return $this->parameters;
