@@ -14,8 +14,7 @@ final class InvalidConstructorClassTypeParameter extends LogicException
     public function __construct(FunctionDefinition $function, Type $type)
     {
         parent::__construct(
-            "Invalid type `{$type->toString()}` for the first parameter of the constructor `{$function->signature()}`, it should be of type `class-string`.",
-            1661517000
+            "Invalid type `{$type->toString()}` for the first parameter of the constructor `{$function->signature}`, it should be of type `class-string`.",
         );
     }
 }
