@@ -12,6 +12,7 @@ use Exception;
 
 use function array_map;
 use function array_shift;
+use function array_values;
 
 /** @internal */
 final class FunctionObjectBuilder implements ObjectBuilder
@@ -49,7 +50,7 @@ final class FunctionObjectBuilder implements ObjectBuilder
         return $this->arguments;
     }
 
-    public function build(array $arguments): object
+    public function buildObject(array $arguments): object
     {
         $parameters = $this->function->definition->parameters;
 
@@ -60,6 +61,7 @@ final class FunctionObjectBuilder implements ObjectBuilder
         $arguments = new MethodArguments($parameters, $arguments);
 
         try {
+            /** @var object */
             return ($this->function->callback)(...$arguments);
         } catch (Exception $exception) {
             throw UserlandError::from($exception);
