@@ -18,7 +18,7 @@ use function strtolower;
  *
  * @implements IteratorAggregate<mixed>
  */
-final class FileSource implements IteratorAggregate, IdentifiableSource
+final class FileSource implements IteratorAggregate
 {
     private string $filePath;
 
@@ -43,11 +43,6 @@ final class FileSource implements IteratorAggregate, IdentifiableSource
         };
     }
 
-    public function sourceName(): string
-    {
-        return $this->filePath;
-    }
-
     /**
      * @return Iterator<mixed>
      */
