@@ -7,5 +7,5 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Shell;
 /** @internal */
 interface NodeBuilder
 {
-    public function build(Shell $shell, RootNodeBuilder $rootBuilder): TreeNode;
+    public function build(Shell $shell): Node;
 }
