@@ -12,19 +12,21 @@ use function assert;
 /** @internal */
 final class ScalarNodeBuilder implements NodeBuilder
 {
-    public function __construct(private bool $enableFlexibleCasting) {}
-
-    public function build(Shell $shell, RootNodeBuilder $rootBuilder): TreeNode
+    public function build(Shell $shell): Node
     {
-        $type = $shell->type();
+        $type = $shell->type;
         $value = $shell->value();
 
         assert($type instanceof ScalarType);
 
-        if (! $this->enableFlexibleCasting || ! $type->canCast($value)) {
-            throw $type->errorMessage();
+        if ($type->accepts($value)) {
+            return $shell->node($value);
         }
 
-        return TreeNode::leaf($shell, $type->cast($value));
+        if (! $shell->allowScalarValueCasting || ! $type->canCast($value)) {
+            return $shell->error($type->errorMessage());
+        }
+
+        return $shell->node($type->cast($value));
     }
 }
