@@ -4,17 +4,16 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Cache\Cache;
 use OCA\Talk\Vendor\CuyZ\Valinor\Library\Container;
 use OCA\Talk\Vendor\CuyZ\Valinor\Library\Settings;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\ArgumentsMapper;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\ErrorMessage;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\TreeMapper;
-use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Format;
-use OCA\Talk\Vendor\CuyZ\Valinor\Normalizer\Normalizer;
-use OCA\Talk\Vendor\Psr\SimpleCache\CacheInterface;
 use Throwable;
 
 use function array_unique;
+use function array_values;
 use function is_callable;
 
 /** @api */
@@ -36,12 +35,12 @@ final class MapperBuilder
      * using the given source. These arguments can then be used to decide which
      * implementation should be used.
      *
-     * The callback *must* be pure, its output must be deterministic.
-     * @see https://en.wikipedia.org/wiki/Pure_function
+     * The callback *must* be pure, its output must be deterministic:
+     * {@see https://en.wikipedia.org/wiki/Pure_function}
      *
      * Example:
      *
-     * ```php
+     * ```
      * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
      *     ->infer(UuidInterface::class, fn () => MyUuid::class)
      *     ->infer(SomeInterface::class, fn (string $type) => match($type) {
@@ -56,8 +55,9 @@ final class MapperBuilder
      *     ]);
      * ```
      *
+     * @pure
      * @param interface-string|class-string $name
-     * @psalm-param pure-callable $callback
+     * @param pure-callable $callback
      */
     public function infer(string $name, callable $callback): self
     {
@@ -69,7 +69,13 @@ final class MapperBuilder
 
     /**
      * Registers a constructor that can be used by the mapper to create an
-     * instance of an object. A constructor is a callable that can be either:
+     * instance of an object.
+     *
+     * Note that depending on your needs, a more straightforward way to register
+     * a constructor is to use the following attribute on a static method:
+     * {@see \OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Object\Constructor}
+     *
+     * A constructor is a callable that can be either:
      *
      * 1. A named constructor, also known as a static factory method
      * 2. The method of a service — for instance a repository
@@ -86,10 +92,7 @@ final class MapperBuilder
      * needs to be handled as well, the name of the class must be given to this
      * method.
      *
-     * A constructor *must* be pure, its output must be deterministic.
-     * @see https://en.wikipedia.org/wiki/Pure_function
-     *
-     * ```php
+     * ```
      * final class SomeClass
      * {
      *     private string $foo;
@@ -137,13 +140,9 @@ final class MapperBuilder
      *     ->registerConstructor(
      *         // Named constructor
      *         SomeClass::namedConstructor(...),
-     *         // …or for PHP < 8.1:
-     *         [SomeClass::class, 'namedConstructor'],
      *
      *         // Method of an object
      *         (new SomeRepository())->findById(...),
-     *         // …or for PHP < 8.1:
-     *         [new SomeRepository(), 'findById'],
      *
      *         // Callable object
      *         new SomeCallableObject(),
@@ -167,7 +166,7 @@ final class MapperBuilder
      *
      * Enum constructors can be registered the same way:
      *
-     * * ```php
+     * ```
      * enum SomeEnum: string
      * {
      *     case CASE_A = 'FOO_VALUE_1';
@@ -175,10 +174,8 @@ final class MapperBuilder
      *     case CASE_C = 'BAR_VALUE_1';
      *     case CASE_D = 'BAR_VALUE_2';
      *
-     *     /**
-     *      * @param 'FOO'|'BAR' $type
-     *      * @param int<1, 2> $number
-     *      * /
+     *     // @param 'FOO'|'BAR' $type
+     *     // @param int<1, 2> $number
      *     public static function fromMatrix(string $type, int $number): self
      *     {
      *         return self::from("{$type}_VALUE_{$number}");
@@ -200,8 +197,11 @@ final class MapperBuilder
      *     ]);
      * ```
      *
-     * @psalm-param pure-callable|class-string ...$constructors
-     * @param callable|class-string ...$constructors
+     * The constructor *must* be pure, its output must be deterministic:
+     * {@see https://en.wikipedia.org/wiki/Pure_function}
+     *
+     * @pure
+     * @param pure-callable|class-string ...$constructors
      */
     public function registerConstructor(callable|string ...$constructors): self
     {
@@ -224,7 +224,7 @@ final class MapperBuilder
      * By default, the dates will accept any valid timestamp or RFC 3339-formatted
      * value.
      *
-     * ```php
+     * ```
      * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
      *     // Both `Cookie` and `ATOM` formats will be accepted
      *     ->supportDateFormats(DATE_COOKIE, DATE_ATOM)
@@ -232,13 +232,14 @@ final class MapperBuilder
      *     ->map(DateTimeInterface::class, 'Monday, 08-Nov-1971 13:37:42 UTC');
      * ```
      *
+     * @pure
      * @param non-empty-string $format
      * @param non-empty-string ...$formats
      */
     public function supportDateFormats(string $format, string ...$formats): self
     {
         $clone = clone $this;
-        $clone->settings->supportedDateFormats = array_unique([$format, ...$formats]);
+        $clone->settings->supportedDateFormats = array_values(array_unique([$format, ...$formats]));
 
         return $clone;
     }
@@ -249,6 +250,7 @@ final class MapperBuilder
      * By default, any valid timestamp or RFC 3339-formatted value are accepted.
      * Custom formats can be set using method `supportDateFormats()`.
      *
+     * @pure
      * @return non-empty-array<non-empty-string>
      */
     public function supportedDateFormats(): array
@@ -258,22 +260,19 @@ final class MapperBuilder
 
     /**
      * Inject a cache implementation that will be in charge of caching heavy
-     * data used by the mapper.
+     * data used by the mapper. It is *strongly* recommended to use it when the
+     * application runs in a production environment.
      *
-     * An implementation is provided by the library, which writes cache entries
-     * in the file system; it is strongly recommended to use it when the
-     * application runs in production environment.
-     *
-     * It is also possible to use any PSR-16 compliant implementation, as long
-     * as it is capable of caching the entries handled by the library.
+     * An implementation is provided out of the box, which writes cache entries
+     * in the file system.
      *
      * When the application runs in a development environment, the cache
-     * implementation should be decorated with `FileWatchingCache`, which will
-     * watch the files of the application and invalidate cache entries when a
-     * PHP file is modified by a developer — preventing the library not behaving
-     * as expected when the signature of a property or a method changes.
+     * implementation should be decorated with `FileWatchingCache`. This service
+     * will watch the files of the application and invalidate cache entries when
+     * a PHP file is modified by a developer — preventing the library not
+     * behaving as expected when the signature of a property or a method changes.
      *
-     * ```php
+     * ```
      * $cache = new \OCA\Talk\Vendor\CuyZ\Valinor\Cache\FileSystemCache('path/to/cache-dir');
      *
      * if ($isApplicationInDevelopmentEnvironment) {
@@ -287,8 +286,10 @@ final class MapperBuilder
      *         // …
      *     ]);
      * ```
+     *
+     * @pure
      */
-    public function withCache(CacheInterface $cache): self
+    public function withCache(Cache $cache): self
     {
         $clone = clone $this;
         $clone->settings->cache = $cache;
@@ -297,86 +298,115 @@ final class MapperBuilder
     }
 
     /**
-     * @template T
-     * @psalm-param pure-callable(T): T $callback
-     * @param callable(T): T $callback
-     */
-    public function alter(callable $callback): self
-    {
-        $clone = clone $this;
-        $clone->settings->valueModifier[] = $callback;
-
-        return $clone;
-    }
-
-    /**
-     * Changes the behaviours explained below:
+     * With this setting enabled, scalar types will accept castable values:
      *
-     * ```php
-     * $flexibleMapper = (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
-     *     ->enableFlexibleCasting()
-     *     ->mapper();
+     * - Integer types will accept any valid numeric value, for instance the
+     *   string value "42".
      *
-     * // ---
-     * // Scalar types will accept non-strict values; for instance an integer
-     * // type will accept any valid numeric value like the *string* "42".
+     * - Float types will accept any valid numeric value, for instance the
+     *   string value "1337.42".
      *
-     * $flexibleMapper->map('int', '42');
-     * // => 42
+     * - String types will accept any integer, float or object implementing the
+     *   `Stringable` interface.
      *
-     * // ---
-     * // List type will accept non-incremental keys.
+     * - Boolean types will accept any truthy or falsy value:
+     *     - "true" (string), "1" (string) and 1 (int) will be cast to `true`
+     *     - "false" (string), "0" (string) and 0 (int) will be cast to `false`
      *
-     * $flexibleMapper->map('list<int>', ['foo' => 42, 'bar' => 1337]);
-     * // => [0 => 42, 1 => 1338]
-     *
-     * // ---
-     * // If a value is missing in a source for a node that accepts `null`, the
-     * // node will be filled with `null`.
-     *
-     * $flexibleMapper->map(
-     *     'array{foo: string, bar: null|string}',
-     *     ['foo' => 'foo'] // `bar` is missing
-     * );
-     * // => ['foo' => 'foo', 'bar' => null]
-     *
-     * // ---
-     * // Array and list types will convert `null` or missing values to an empty
-     * // array.
-     *
-     * $flexibleMapper->map(
-     *     'array{foo: string, bar: array<string>}',
-     *     ['foo' => 'foo'] // `bar` is missing
-     * );
-     * // => ['foo' => 'foo', 'bar' => []]
      * ```
+     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *     ->allowScalarValueCasting()
+     *     ->mapper()
+     *     ->map('array{id: string, price: float, active: bool}', [
+     *         'id' => 549465210, // Will be cast to string
+     *         'price' => '42.39', // Will be cast to float
+     *         'active' => 1, // Will be cast to bool
+     *     ]);
+     * ```
+     *
+     * @pure
      */
-    public function enableFlexibleCasting(): self
+    public function allowScalarValueCasting(): self
     {
         $clone = clone $this;
-        $clone->settings->enableFlexibleCasting = true;
+        $clone->settings->allowScalarValueCasting = true;
 
         return $clone;
     }
 
     /**
-     * Superfluous keys in source arrays will be ignored, preventing errors when
-     * a value is not bound to any object property/parameter or shaped array
-     * element.
+     * By default, list types will only accept sequential keys starting from 0.
      *
-     * ```php
+     * This setting allows the mapper to convert associative arrays to a list
+     * with sequential keys.
+     *
+     * ```
+     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *     ->allowNonSequentialList()
+     *     ->mapper()
+     *     ->map('list<int>', [
+     *         'foo' => 42,
+     *         'bar' => 1337,
+     *     ]);
+     *
+     * // => [0 => 42, 1 => 1337]
+     * ```
+     *
+     * @pure
+     */
+    public function allowNonSequentialList(): self
+    {
+        $clone = clone $this;
+        $clone->settings->allowNonSequentialList = true;
+
+        return $clone;
+    }
+
+    /**
+     * Allows the mapper to accept undefined values (missing from the input), by
+     * converting them to `null` (if the current type is nullable) or an empty
+     * array (if the current type is an object or an iterable).
+     *
+     * ```
+     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *     ->allowUndefinedValues()
+     *     ->mapper()
+     *     ->map('array{name: string, age: int|null}', [
+     *         'name' => 'John Doe',
+     *         // 'age' is not defined
+     *     ]);
+     *
+     * // => ['name' => 'John Doe', 'age' => null]
+     * ```
+     *
+     * @pure
+     */
+    public function allowUndefinedValues(): self
+    {
+        $clone = clone $this;
+        $clone->settings->allowUndefinedValues = true;
+
+        return $clone;
+    }
+
+    /**
+     * By default, an error is raised when a source array contains keys that
+     * do not match a class property/parameter or a shaped array element.
+     *
+     * This setting allows the mapper to ignore these superfluous keys.
+     *
+     * ```
      * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
      *     ->allowSuperfluousKeys()
      *     ->mapper()
-     *     ->map(
-     *         'array{foo: string, bar: int}',
-     *         [
-     *             'foo' => 'foo',
-     *             'bar' => 42,
-     *             'baz' => 1337.404, // `baz` will be ignored
-     *         ]
-     *     );
+     *     ->map('array{name: string, age: int}', [
+     *         'name' => 'John Doe',
+     *         'age' => 42,
+     *         'city' => 'Paris', // Will be ignored
+     *     ]);
      * ```
+     *
+     * @pure
      */
     public function allowSuperfluousKeys(): self
     {
@@ -389,18 +419,17 @@ final class MapperBuilder
     /**
      * Allows permissive types `mixed` and `object` to be used during mapping.
      *
-     * ```php
+     * ```
      * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
      *     ->allowPermissiveTypes()
      *     ->mapper()
-     *     ->map(
-     *         'array{foo: string, bar: mixed}',
-     *         [
-     *             'foo' => 'foo',
-     *             'bar' => 42, // Could be any value
-     *         ]
-     *     );
+     *     ->map('array{name: string, data: mixed}', [
+     *         'name' => 'some_product',
+     *         'data' => 42, // Could be any value
+     *     ]);
      * ```
+     *
+     * @pure
      */
     public function allowPermissiveTypes(): self
     {
@@ -410,6 +439,112 @@ final class MapperBuilder
         return $clone;
     }
 
+    /**
+     * A mapper converter allows users to hook into the mapping process and
+     * apply custom logic to the input, by defining a callable signature that
+     * properly describes when it should be called:
+     *
+     * - A first argument with a type matching the expected input being mapped
+     * - A return type representing the targeted mapped type
+     *
+     * These two types are enough for the library to know when to call the
+     * converter and can contain advanced type annotations for more specific
+     * use cases.
+     *
+     * Below is a basic example of a converter that converts string inputs to
+     * uppercase:
+     *
+     * ```
+     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *     ->registerConverter(fn (string $value): string => strtoupper($value))
+     *     ->mapper()
+     *     ->map('string', 'hello world'); // 'HELLO WORLD'
+     * ```
+     *
+     * Converters can be chained, allowing multiple transformations to be
+     * applied to a value. A second `callable` parameter can be declared,
+     * allowing the current converter to call the next one in the chain.
+     *
+     * A priority can be given to a converter to control the order in which
+     * converters are applied. The higher the priority, the earlier the
+     * converter will be executed. The default priority is 0.
+     *
+     * An attribute on a property or a class can act as a converter if:
+     *  1. It defines a `map` method.
+     *  2. It is registered using either the `registerConverter()` method or
+     *     the following attribute: {@see \OCA\Talk\Vendor\CuyZ\Valinor\Mapper\AsConverter}
+     *
+     * ```
+     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *
+     *     // The type of the first parameter of the converter will determine
+     *     // when it will be used by the mapper.
+     *     ->registerConverter(
+     *         fn (string $value, callable $next): string => $next(strtoupper($value))
+     *     )
+     *
+     *     // Converters can be chained, the last registered one will take
+     *     // precedence over the previous ones, which can be called using the
+     *     // `$next` parameter.
+     *     ->registerConverter(
+     *         fn (string $value, callable $next): string => $next($value . '!')
+     *     )
+     *
+     *     // A priority can be given to a converter, to make sure it is called
+     *     // before or after another one.
+     *     ->registerConverter(
+     *         fn (string $value, callable $next): string => $next($value . '?'),
+     *         priority: -100 // Negative priority: converter is called early
+     *     )
+     *
+     *     // External converter attributes must be registered before they are
+     *     // used by the mapper.
+     *     ->registerConverter(\Some\External\ConverterAttribute::class)
+     *
+     *     ->mapper()
+     *     ->map('string', 'hello world'); // 'HELLO WORLD!?'
+     * ```
+     *
+     * It is also possible to register attributes that share a common interface
+     * by giving the interface name to the registration method.
+     *
+     * ```
+     * namespace My\App;
+     *
+     * interface MyAttributeInterface {}
+     *
+     * #[\Attribute]
+     * final class SomeAttribute implements \My\App\MyAttributeInterface {}
+     *
+     * #[\Attribute]
+     * final class SomeOtherAttribute implements \My\App\MyAttributeInterface {}
+     *
+     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *     // Registers both `SomeAttribute` and `SomeOtherAttribute` attributes
+     *     ->registerConverter(\My\App\MyAttributeInterface::class)
+     *     ->mapper()
+     *     ->map(…);
+     * ```
+     *
+     * The converter *must* be pure, its output must be deterministic:
+     * {@see https://en.wikipedia.org/wiki/Pure_function}
+     *
+     * @pure
+     * @param pure-callable|class-string $converter
+     */
+    public function registerConverter(callable|string $converter, int $priority = 0): self
+    {
+        $clone = clone $this;
+
+        if (is_callable($converter)) {
+            $clone->settings->mapperConverters[$priority][] = $converter;
+        } else {
+            $clone->settings->mapperConverterAttributes[$converter] = null;
+        }
+
+        return $clone;
+    }
+
     /**
      * Filters which userland exceptions are allowed during the mapping.
      *
@@ -418,10 +553,7 @@ final class MapperBuilder
      * part of a query should never be allowed. Therefore, only an exhaustive
      * list of carefully chosen exceptions should be filtered.
      *
-     * The filter callback *must* be pure, its output must be deterministic.
-     * @see https://en.wikipedia.org/wiki/Pure_function
-     *
-     * ```php
+     * ```
      * final class SomeClass
      * {
      *     public function __construct(string $value)
@@ -446,7 +578,7 @@ final class MapperBuilder
      *     ]);
      * ```
      *
-     * @psalm-param pure-callable(Throwable): ErrorMessage $filter
+     * @pure
      * @param callable(Throwable): ErrorMessage $filter
      */
     public function filterExceptions(callable $filter): self
@@ -458,109 +590,63 @@ final class MapperBuilder
     }
 
     /**
-     * A transformer is responsible for transforming specific values during a
-     * normalization process.
+     * Warms up the injected cache implementation with the provided type
+     * signatures. This will improve the performance when the first call to the
+     * mapper is done for each of these types.
      *
-     * Transformers can be chained, the last registered one will take precedence
-     * over the previous ones.
-     *
-     * By specifying the type of its first parameter, the given callable will
-     * determine when the transformer is used. Advanced type annotations like
-     * `non-empty-string` can be used to target a more specific type.
-     *
-     * A second `callable` parameter may be declared, allowing to call the next
-     * transformer in the chain and get the modified value from it, before
-     * applying its own transformations.
-     *
-     * A priority can be given to a transformer, to make sure it is called
-     * before or after another one. The higher the priority, the sooner the
-     * transformer will be called. Default priority is 0.
-     *
-     * An attribute on a property or a class can act as a transformer if:
-     *  1. It is callable (they define an `__invoke` method)
-     *  2. It is registered using `registerTransformer()`
-     *
-     * Example:
-     *
-     * ```php
-     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
-     *
-     *     // The type of the first parameter of the transformer will determine
-     *     // when it will be used by the normalizer.
-     *     ->registerTransformer(
-     *         fn (string $value, callable $next) => strtoupper($next())
-     *     )
-     *
-     *     // Transformers can be chained, the last registered one will take
-     *     // precedence over the previous ones, which can be called using the
-     *     // `$next` parameter.
-     *     ->registerTransformer(
-     *         fn (string $value, callable $next) => $next() . '!'
-     *     )
-     *
-     *     // A priority can be given to a transformer, to make sure it is
-     *     // called before or after another one.
-     *     ->registerTransformer(
-     *         fn (string $value, callable $next) => $next() . '?',
-     *         priority: -100 // Negative priority: transformer is called early
-     *     )
-     *
-     *     // Transformer attributes must be registered before they are used by
-     *     // the normalizer.
-     *     ->registerTransformer(SomeAttribute::class)
-     *
-     *     ->normalizer()
-     *     ->normalize('Hello world'); // HELLO WORLD?!
      * ```
+     * $mapperBuilder = (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *    ->withCache(new \OCA\Talk\Vendor\CuyZ\Valinor\Cache\FileSystemCache('path/to/dir'));
      *
-     * @psalm-param pure-callable|class-string $transformer
-     * @param callable|class-string $transformer
+     * // During the build:
+     * $mapperBuilder->warmupCacheFor(
+     *        // This will also recursively warm up the cache for the types of
+     *        // the class properties.
+     *        SomeClass::class,
+     *
+     *        // Any valid type signature can be used.
+     *        'non-empty-list<string, SomeClass>',
+     *        'array{name: string, age: int}',
+     *    );
+     *
+     * // In the application:
+     * $mapperBuilder->mapper()->map(SomeClass::class, […]);
+     * ```
      */
-    public function registerTransformer(callable|string $transformer, int $priority = 0): self
+    public function warmupCacheFor(string ...$signatures): void
     {
-        $clone = clone $this;
-
-        if (is_callable($transformer)) {
-            $clone->settings->transformers[$priority][] = $transformer;
-        } else {
-            $clone->settings->transformerAttributes[$transformer] = null;
+        if (! isset($this->settings->cache)) {
+            return;
         }
 
-        return $clone;
-    }
-
-    /**
-     * Warms up the injected cache implementation with the provided class names.
-     *
-     * By passing a class which contains recursive objects, every nested object
-     * will be cached as well.
-     */
-    public function warmup(string ...$signatures): void
-    {
         $this->container()->cacheWarmupService()->warmup(...$signatures);
     }
 
+    /**
+     * Clears all persisted cache entries from the registered cache
+     * implementation.
+     */
+    public function clearCache(): void
+    {
+        if (! isset($this->settings->cache)) {
+            return;
+        }
+
+        $this->settings->cache->clear();
+    }
+
+    /** @pure */
     public function mapper(): TreeMapper
     {
         return $this->container()->treeMapper();
     }
 
+    /** @pure */
     public function argumentsMapper(): ArgumentsMapper
     {
         return $this->container()->argumentsMapper();
     }
 
-    /**
-     * @template T of Normalizer
-     *
-     * @param Format<T> $format
-     * @return T
-     */
-    public function normalizer(Format $format): Normalizer
-    {
-        return $this->container()->normalizer($format);
-    }
-
     public function __clone()
     {
         $this->settings = clone $this->settings;
