@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Types;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Native\ComplianceNode;
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Node;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\ErrorMessage;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\MessageBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\FloatType;
@@ -24,6 +26,11 @@ final class NativeFloatType implements FloatType
         return is_float($value);
     }
 
+    public function compiledAccept(ComplianceNode $node): ComplianceNode
+    {
+        return Node::functionCall('is_float', [$node]);
+    }
+
     public function matches(Type $other): bool
     {
         if ($other instanceof UnionType) {
@@ -31,9 +38,15 @@ final class NativeFloatType implements FloatType
         }
 
         return $other instanceof self
+            || $other instanceof ScalarConcreteType
             || $other instanceof MixedType;
     }
 
+    public function inferGenericsFrom(Type $other, Generics $generics): Generics
+    {
+        return $generics;
+    }
+
     public function canCast(mixed $value): bool
     {
         return is_numeric($value);
@@ -48,7 +61,14 @@ final class NativeFloatType implements FloatType
 
     public function errorMessage(): ErrorMessage
     {
-        return MessageBuilder::newError('Value {source_value} is not a valid float.')->build();
+        return MessageBuilder::newError('Value {source_value} is not a valid float.')
+            ->withCode('invalid_float')
+            ->build();
+    }
+
+    public function nativeType(): NativeFloatType
+    {
+        return $this;
     }
 
     public function toString(): string
