@@ -12,6 +12,10 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Type\IntegerType;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 use OCA\Talk\Vendor\CuyZ\Valinor\Utility\IsSingleton;
 
+use function assert;
+use function filter_var;
+use function is_bool;
+use function is_int;
 use function is_string;
 use function ltrim;
 
@@ -36,16 +40,25 @@ final class NonNegativeIntegerType implements IntegerType
             return $other->isMatchedBy($this);
         }
 
+        if ($other instanceof ArrayKeyType) {
+            return $other->isMatchedBy($this);
+        }
+
         return $other instanceof self
             || $other instanceof NativeIntegerType
             || $other instanceof ScalarConcreteType
             || $other instanceof MixedType;
     }
 
+    public function inferGenericsFrom(Type $other, Generics $generics): Generics
+    {
+        return $generics;
+    }
+
     public function canCast(mixed $value): bool
     {
-        if (is_string($value)) {
-            $value = ltrim($value, '0') . '0';
+        if (is_string($value) && $value !== '') {
+            $value = ltrim($value, '0') ?: '0';
         }
 
         return ! is_bool($value)
@@ -62,7 +75,9 @@ final class NonNegativeIntegerType implements IntegerType
 
     public function errorMessage(): ErrorMessage
     {
-        return MessageBuilder::newError('Value {source_value} is not a valid non-negative integer.')->build();
+        return MessageBuilder::newError('Value {source_value} is not a valid non-negative integer.')
+            ->withCode('invalid_non_negative_integer')
+            ->build();
     }
 
     public function nativeType(): NativeIntegerType
