@@ -6,7 +6,6 @@ namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Types;
 
 use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Native\ComplianceNode;
 use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Node;
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\ObjectType;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 use OCA\Talk\Vendor\CuyZ\Valinor\Utility\IsSingleton;
 
@@ -34,11 +33,14 @@ final class UndefinedObjectType implements Type
         }
 
         return $other instanceof self
-            || $other instanceof ObjectType
-            || $other instanceof IntersectionType
             || $other instanceof MixedType;
     }
 
+    public function inferGenericsFrom(Type $other, Generics $generics): Generics
+    {
+        return $generics;
+    }
+
     public function nativeType(): UndefinedObjectType
     {
         return $this;
